<?php
require_once(__DIR__ . "/AdjustmentService.php");
require_once(__DIR__ . "/AdjustmentModel.php");
require_once(__DIR__ . "/../Veritabani.php");

class AdjustmentServiceImp extends Veritabani implements AdjustmentService{

    public function __construct(){
        parent::__construct();
    }


    public function queryAdjustmentServiceFetch(){
        $response = array();

        $queryAdjustmentFetch = $this->baglanti->query("SELECT * FROM ayarlar");
        $queryAdjustmentFetch->execute();
        $adjustmentFetchResponse = $queryAdjustmentFetch->fetchAll(PDO::FETCH_ASSOC);

        if($adjustmentFetchResponse){
            $response["adjustment"] = $this->addAdjustmentService($adjustmentFetchResponse[0]);
            $response["success"] = parent::BASARILI;
            $response["message"] = "Salon bilgileri başarıyla alındı";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Salon bilgileri alınamadı";
        }

        return $response;
    }

    public function updateHallInformation($adjustment){
        $response = array();

        $mobilePhone = $adjustment->getMobilePhone();
        $landPhone   = $adjustment->getLandPhone();
        $mailAddress = $adjustment->getMailAddress();
        $latitude    = $adjustment->getLatitude();
        $longitude   = $adjustment->getLongitude();


        $updateInformation = $this->baglanti->prepare("UPDATE ayarlar SET
                                                        salon_cep_telefon   = :cep_telefon,
                                                        salon_sabit_telefon = :sabit_telefon,
                                                        salon_mail_adres    = :mail_adres,
                                                        enlem               = :enlem,
                                                        boylam              = :boylam
                                                        WHERE ayar_id = 1");
        $updateInformation->bindParam(":cep_telefon"  ,$mobilePhone, PDO::PARAM_STR);
        $updateInformation->bindParam(":sabit_telefon",$landPhone  , PDO::PARAM_STR);
        $updateInformation->bindParam(":mail_adres"   ,$mailAddress, PDO::PARAM_STR);
        $updateInformation->bindParam(":enlem"        ,$latitude   , PDO::PARAM_STR);
        $updateInformation->bindParam(":boylam"       ,$longitude  , PDO::PARAM_STR);
        $updateInformation->execute();

        if($updateInformation){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Salon bilgileri başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Salon bilgileri güncellenirke hata ile karşılaşıldı";
        }

        return $response;
    }

    public function webUpdateHallInformation($adjustment){
        $response = array();

        $hallName    = $adjustment->getHallName();
        $mobilePhone = $adjustment->getMobilePhone();
        $landPhone   = $adjustment->getLandPhone();
        $mailAddress = $adjustment->getMailAddress();
        $latitude    = $adjustment->getLatitude();
        $longitude   = $adjustment->getLongitude();


        $updateInformation = $this->baglanti->prepare("UPDATE ayarlar SET
                                                        salon_adi           = :salon_adi,
                                                        salon_cep_telefon   = :cep_telefon,
                                                        salon_sabit_telefon = :sabit_telefon,
                                                        salon_mail_adres    = :mail_adres,
                                                        enlem               = :enlem,
                                                        boylam              = :boylam
                                                        WHERE ayar_id = 1");
        $updateInformation->bindParam(":salon_adi"    ,$hallName   , PDO::PARAM_STR);
        $updateInformation->bindParam(":cep_telefon"  ,$mobilePhone, PDO::PARAM_STR);
        $updateInformation->bindParam(":sabit_telefon",$landPhone  , PDO::PARAM_STR);
        $updateInformation->bindParam(":mail_adres"   ,$mailAddress, PDO::PARAM_STR);
        $updateInformation->bindParam(":enlem"        ,$latitude   , PDO::PARAM_STR);
        $updateInformation->bindParam(":boylam"       ,$longitude  , PDO::PARAM_STR);
        $updateInformation->execute();

        if($updateInformation){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Salon bilgileri başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Salon bilgileri güncellenirke hata ile karşılaşıldı";
        }

        return $response;
    }

    public function addAdjustmentService($adjustmentService){
        $adjustmentModel = new AdjustmentModel();

        $adjustmentModel->setAdjustmentId($adjustmentService["ayar_id"]);
        $adjustmentModel->setHallName($adjustmentService["salon_adi"]);
        $adjustmentModel->setHallLocation($adjustmentService["salon_adresi"]);
        $adjustmentModel->setMobilePhone($adjustmentService["salon_cep_telefon"]);
        $adjustmentModel->setLandPhone($adjustmentService["salon_sabit_telefon"]);
        $adjustmentModel->setMailAddress($adjustmentService["salon_mail_adres"]);
        $adjustmentModel->setHallAboutUs($adjustmentService["salon_hakkimizda"]);
        $adjustmentModel->setHallAboutUsImage($adjustmentService["salon_hakkimizda_fotograf"]);
        $adjustmentModel->setLatitude($adjustmentService["enlem"]);
        $adjustmentModel->setLongitude($adjustmentService["boylam"]);

        return $adjustmentModel->toString();
    }

    public function __destruct(){
        parent::__destruct();
    }

    
}



?>