<?php
require_once(__DIR__ . "/AppointmentRulerModel.php");
require_once(__DIR__ . "/AppointmentRulerService.php");
require_once(__DIR__ . "/../Veritabani.php");

class AppointmentRulerServiceImp extends Veritabani implements AppointmentRulerService{

    public function __construct(){
        parent::__construct();
    }

    public function fetchAppointmentRulerByProductId($service_id){
        $response = array();

        $queryAppointmentRulerDate = $this->baglanti->prepare("SELECT * FROM randevu_cetveli WHERE hizmet_id = :hizmet_id GROUP BY randevu_tarih");
        $queryAppointmentRulerDate->bindValue(":hizmet_id", $service_id, PDO::PARAM_INT);
        $queryAppointmentRulerDate->execute();
        $appointmentRulerDateResponse = $queryAppointmentRulerDate->fetchAll(PDO::FETCH_ASSOC);

        if($appointmentRulerDateResponse){
            $response["appointmentRulers"] = array();

            foreach($appointmentRulerDateResponse as $appointmentRuler){
                $appointmentDate = $appointmentRuler["randevu_tarih"];
                $deneme = array();
                $deneme["appointmentDate"] = $appointmentDate;
                

                $queryAppointmentRulerItem = $this->baglanti->prepare("SELECT hizmet.hizmet_id, hizmet.hizmet_adi,
                                                                              hizmet.tahmini_hizmet_suresi, hizmet.hizmet_onizleme_url , cetvel.cetvel_id,
                                                                              cetvel.randevu_tarih, cetvel.randevu_saat,
                                                                              cetvel.randevu_durum 
                                                                        FROM randevu_cetveli as cetvel
                                                                        INNER JOIN hizmetler as hizmet on hizmet.hizmet_id = cetvel.hizmet_id
                                                                        WHERE cetvel.hizmet_id = :hizmet_id AND cetvel.randevu_tarih = :randevu_tarih");
                $queryAppointmentRulerItem->bindValue(":hizmet_id"    , $service_id     , PDO::PARAM_INT);
                $queryAppointmentRulerItem->bindValue(":randevu_tarih", $appointmentDate, PDO::PARAM_STR);
                $queryAppointmentRulerItem->execute();
                $appointmentRulerItemResponse = $queryAppointmentRulerItem->fetchAll(PDO::FETCH_ASSOC);

                if($appointmentRulerItemResponse){
                    $rulerItem = array();

                    foreach($appointmentRulerItemResponse as $appointmentRulerItem){
                        $appointmentRulerModel = $this->addAppointmentRulerModel($appointmentRulerItem);
                        array_push($rulerItem,$appointmentRulerModel);
                    }
                    $deneme["appointmentRulersItem"] = $rulerItem;
                    array_push($response["appointmentRulers"],$deneme);
                    $response["success"] = parent::BASARILI;
                    $response["message"] = "Randevu cetveli başarıyla çekildi";
                }else{
                    $response["success"] = parent::BASARISIZ;
                    $response["message"] = "Randevu cetveli bulunamadı";
                }
            }
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Bu hizmete ait randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchAppointmentRulerTimeById($rulerId){

        $fetchRulerTime = $this->baglanti->query("SELECT * FROM randevu_cetveli WHERE cetvel_id = $rulerId")->fetch(PDO::FETCH_OBJ);

        return $fetchRulerTime;
    }


    public function fetchAppointmentRulerByDateAndServicesId($date, $serviceId){
        $response = array();


        $queryAppointmentRuler = $this->baglanti->prepare("SELECT * FROM randevu_cetveli as cetvel
                                                           INNER JOIN hizmetler as hizmet on hizmet.hizmet_id = cetvel.hizmet_id
                                                           WHERE cetvel.hizmet_id = :hizmet_id AND cetvel.randevu_tarih = :randevu_tarih AND randevu_durum = 1");
        $queryAppointmentRuler->bindValue(":hizmet_id"    , $serviceId , PDO::PARAM_INT);
        $queryAppointmentRuler->bindValue(":randevu_tarih", $date      , PDO::PARAM_STR);
        $queryAppointmentRuler->execute();

        $responseAppointmentRuler = $queryAppointmentRuler->fetchAll(PDO::FETCH_ASSOC);

        if($responseAppointmentRuler){
            $response["appointmentRulers"] = array();

            foreach($responseAppointmentRuler as $appointmentRuler){
                $appointmentRulerModel = $this->addAppointmentRulerModel($appointmentRuler);
                array_push($response["appointmentRulers"],$appointmentRulerModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevu bilgileri getirildi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Üzgünüz, " . $date . " ait randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function deleteAppointmentRuler($rulerId){
        $response = array();

        $appointmentRuler = $this->baglanti->prepare("SELECT * FROM randevu_cetveli WHERE cetvel_id = :cetvel_id");
        $appointmentRuler->bindValue("cetvel_id",$rulerId);
        $appointmentRuler->execute();
        $responseAppointmentRuler = $appointmentRuler->fetch(PDO::FETCH_OBJ);

        if($responseAppointmentRuler->randevu_durum == 1){
            $deleteAppointmentRuler = $this->baglanti->prepare("DELETE FROM randevu_cetveli WHERE cetvel_id = :cetvel_id");
            $deleteAppointmentRuler->bindValue("cetvel_id",$rulerId);
            $deleteAppointmentRuler->execute();

            if($deleteAppointmentRuler->rowCount() > 0){
                $response["success"] = parent::BASARILI;
                $response["message"] = "Randevu cetveli başarıyla silindi";
            }else{
                $response["success"] = parent::BASARISIZ;
                $response["message"] = "Randevu cetveli silinemiyor";
            }
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Randevu cetveli silinemiyor. Randevu alınmış olabilir";
        }

        return $response;
    }

    public function  addAppointmentRuler($serviceId, $appointmentDate, $rulerTimeList){

        $this->baglanti->beginTransaction();

        foreach($rulerTimeList as $time){
            $this->baglanti->exec("INSERT INTO randevu_cetveli(randevu_tarih, randevu_saat ,hizmet_id)
                                    VALUES('$appointmentDate', '$time', '$serviceId')");
        }

        $this->baglanti->commit();

        $response["success"] = parent::BASARILI;
        $response["message"] = "Randevu cetveli başarıyla oluşturuldu" . $this->baglanti->lastInsertId();

        return $response;
    }

    public function addAppointmentRulerModel($appointmentRuler){
        $appointmentRulerModel = new AppointmentRulerModel();

        $appointmentRulerModel->setRulerId($appointmentRuler["cetvel_id"]);
        $appointmentRulerModel->setAppointmentDate($appointmentRuler["randevu_tarih"]);
        $appointmentRulerModel->setAppointmentTime($appointmentRuler["randevu_saat"]);
        $appointmentRulerModel->setAppointmentStatus($appointmentRuler["randevu_durum"]);
        $appointmentRulerModel->setServiceId($appointmentRuler["hizmet_id"]);
        $appointmentRulerModel->setServiceName($appointmentRuler["hizmet_adi"]);
        $appointmentRulerModel->setServiceTime($appointmentRuler["tahmini_hizmet_suresi"]);
        $appointmentRulerModel->setServicePreviewUrl($appointmentRuler["hizmet_onizleme_url"]);

        return $appointmentRulerModel->toString();
    }

    public function __destruct(){
        parent::__destruct();
    }

}
?>