<?php
require_once(__DIR__ . "/AppointmentModel.php");
require_once(__DIR__ . "/AppointmentsService.php");
require_once(__DIR__ . "/../appointmentRuler/AppointmentRulerModel.php");
require_once(__DIR__ . "/../Veritabani.php");
require_once(__DIR__ . "/../appointmentRuler/AppointmentRulerServiceImp.php");
require_once(__DIR__ . "/../../utility/InstallmentTransactions.php");

class AppointmentsServiceImp extends Veritabani implements AppointmentsService{


    public function __construct(){
        parent::__construct();
    }

    public function randevuIdyeGoreMusteriAdSoyadGetir($randevuId){
        $kullaniciSorgu = $this->baglanti->prepare("SELECT kullanicilar.ad, kullanicilar.soyad FROM randevular 
                                                            INNER JOIN kullanicilar ON kullanicilar.musteri_id = randevular.musteri_id
                                                            WHERE randevular.randevu_id = :randevu_id");
        $kullaniciSorgu->bindValue(":randevu_id",$randevuId);
        $kullaniciSorgu->execute();
        $kullaniciCevap = $kullaniciSorgu->fetch(PDO::FETCH_OBJ);

        return $kullaniciCevap;
    }

    public function webFetchAppointmentsById($costumer_id){
        $response = array();

        $appointmentsToday = $this->baglanti->prepare("SELECT * FROM appointmenttakers 
                                                                INNER JOIN randevular ON randevular.randevu_id = appointmenttakers.randevu_id
                                                                WHERE randevular.musteri_id = :costumer_id ");
        $appointmentsToday->bindValue(":costumer_id",$costumer_id);
        $appointmentsToday->execute();
        $appointmentsTodayResponse = $appointmentsToday->fetchAll(PDO::FETCH_ASSOC);

        if($appointmentsTodayResponse){
            $response["appointments"] = array();

            foreach($appointmentsTodayResponse as $appointment){
                $appointmentModel = $this->addAppointmentTodayModel($appointment);
                array_push($response["appointments"],$appointmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevular başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchAppointmentsById($costumer_id){
        $response = array();

        $appointmentQuery = $this->baglanti->prepare("SELECT
                                                        randevu.randevu_id, randevu.randevu_tarih, randevu.randevu_saat,
                                                        hizmet.hizmet_id, hizmet.hizmet_adi, hizmet.tahmini_hizmet_suresi,
                                                        hizmet.hizmet_onizleme_url, randevu.durum_id
                                                      FROM randevular as randevu
                                                            INNER JOIN musteriler as musteri ON musteri.musteri_id = randevu.musteri_id
                                                            INNER JOIN hizmetler  as hizmet  ON hizmet.hizmet_id   = randevu.hizmet_id
                                                            WHERE randevu.musteri_id = :musteri_id");
        $appointmentQuery->bindValue(":musteri_id", $costumer_id, PDO::PARAM_INT);
        $appointmentQuery->execute();
        $appointmentResponse = $appointmentQuery->fetchAll(PDO::FETCH_ASSOC);

        if($appointmentResponse){
            $response["appointments"] = array();

            foreach($appointmentResponse as $appointment){
                $appointmentModel = $this->addAppointmentModel($appointment);
                array_push($response["appointments"],$appointmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevular başarıyla çekildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchPastViewAppointment($appointmentId){
        $response = array();

        $appointmentQuery = $this->baglanti->prepare("SELECT * FROM appointmenttakers2 WHERE randevu_id = :appointment_id");
        $appointmentQuery->bindValue(":appointment_id", $appointmentId);
        $appointmentQuery->execute();
        $appointmentResponse = $appointmentQuery->fetch(PDO::FETCH_OBJ);

        if($appointmentResponse){
            $response["appointment"] = $appointmentResponse;
            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevu başarıyla çekildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchAppointmentById($appointmentId){
        $response = array();

        $appointmentQuery = $this->baglanti->prepare("SELECT * FROM randevular WHERE randevu_id = :appointment_id");
        $appointmentQuery->bindValue(":appointment_id", $appointmentId);
        $appointmentQuery->execute();
        $appointmentResponse = $appointmentQuery->fetch(PDO::FETCH_ASSOC);

        if($appointmentResponse){
            $response["appointment"] = $appointmentResponse;
            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevu başarıyla çekildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchUpcomingAppointments($costumer_id){
        $response = array();

        $activeStatusId = 1;

        $upComingAppointmentQuery = $this->baglanti->prepare("SELECT
                                                                randevu.randevu_id, randevu.randevu_tarih, randevu.randevu_saat,
                                                                hizmet.hizmet_id, hizmet.hizmet_adi, hizmet.tahmini_hizmet_suresi,
                                                                hizmet.hizmet_onizleme_url, randevu.durum_id
                                                            FROM randevular as randevu
                                                            INNER JOIN kullanicilar as musteri ON musteri.musteri_id = randevu.musteri_id
                                                            INNER JOIN hizmetler  as hizmet  ON hizmet.hizmet_id   = randevu.hizmet_id
                                                            WHERE randevu.musteri_id = :musteri_id AND randevu.durum_id = :durum_id");
        $upComingAppointmentQuery->bindValue(":musteri_id", $costumer_id   , PDO::PARAM_INT);
        $upComingAppointmentQuery->bindValue(":durum_id"  , $activeStatusId, PDO::PARAM_INT);
        $upComingAppointmentQuery->execute();
        $upComingAppointmentResponse = $upComingAppointmentQuery->fetchAll(PDO::FETCH_ASSOC);

        if($upComingAppointmentResponse){
            $response["appointments"] = array();

            foreach($upComingAppointmentResponse as $appointment){
                $appointmentModel = $this->addAppointmentModel($appointment);
                array_push($response["appointments"],$appointmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevular başarıyla çekildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function updateAppointment($appointmentModel){
        $response = array();

        $appointmentId = $appointmentModel->getAppointmentId();
        $appointmentDate = $appointmentModel->getAppointmentDate();
        $appointmentTime = $appointmentModel->getAppointmentTime();
        $appointmentDetail = $appointmentModel->getAppointmentDetail();

        $updateAppointment = $this->baglanti->prepare("UPDATE randevular SET randevu_tarih = :randevu_tarih, randevu_saat = :randevu_saat,
                                                                                   randevu_detay = :randevu_detay, durum_id = :durum_id WHERE randevu_id = :randevu_id");
        $updateAppointment->bindValue("randevu_tarih"  ,$appointmentDate);
        $updateAppointment->bindValue("randevu_saat",$appointmentTime);
        $updateAppointment->bindValue("randevu_detay",$appointmentDetail);
        $updateAppointment->bindValue("durum_id",1);
        $updateAppointment->bindValue("randevu_id",$appointmentId);
        $updateAppointment->execute();

        if($updateAppointment->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevu başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Güncellenirken hata oluştu";
        }

        return $response;

    }

    public function updateAppointmentStatus($appointment_id, $status){
        $response = array();

        $updateAppointment = $this->baglanti->prepare("UPDATE randevular SET durum_id = :durum_id WHERE randevu_id = :randevu_id");
        $updateAppointment->bindValue("durum_id"  ,$status);
        $updateAppointment->bindValue("randevu_id",$appointment_id);
        $updateAppointment->execute();

        if($updateAppointment->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevu başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Güncellenirken hata oluştu";
        }

        return $response;
    }


    public function fetchPastAppointments($costumer_id){
        $response = array();

        $unActiveStatusId = 2;

        $upComingAppointmentQuery = $this->baglanti->prepare("SELECT
                                                                randevu.randevu_id, randevu.randevu_tarih, randevu.randevu_saat,
                                                                hizmet.hizmet_id, hizmet.hizmet_adi, hizmet.tahmini_hizmet_suresi,
                                                                hizmet.hizmet_onizleme_url, randevu.durum_id
                                                            FROM randevular as randevu
                                                            INNER JOIN kullanicilar as musteri ON musteri.musteri_id = randevu.musteri_id
                                                            INNER JOIN hizmetler  as hizmet  ON hizmet.hizmet_id   = randevu.hizmet_id
                                                            WHERE randevu.musteri_id = :musteri_id AND randevu.durum_id = :durum_id");
        $upComingAppointmentQuery->bindValue(":musteri_id", $costumer_id   , PDO::PARAM_INT);
        $upComingAppointmentQuery->bindValue(":durum_id"  , $unActiveStatusId, PDO::PARAM_INT);
        $upComingAppointmentQuery->execute();
        $upComingAppointmentResponse = $upComingAppointmentQuery->fetchAll(PDO::FETCH_ASSOC);

        if($upComingAppointmentResponse){
            $response["appointments"] = array();

            foreach($upComingAppointmentResponse as $appointment){
                $appointmentModel = $this->addAppointmentModel($appointment);
                array_push($response["appointments"],$appointmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevular başarıyla çekildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function queryAddAppointment($appointmentModel){
        $response = array();

        $appointmentDate    = $appointmentModel->getAppointmentDate();
        $appointmentTime    = $appointmentModel->getAppointmentTime();
        $productId          = $appointmentModel->getServiceId();
        $costumerId         = $appointmentModel->getCostumerId();
        $appointmentDetails = $appointmentModel->getAppointmentDetail();


        $queryAddAppointment = $this->baglanti->prepare("INSERT INTO randevular(randevu_tarih, randevu_saat, hizmet_id, musteri_id, randevu_detay)
                                                         VALUES(?,?,?,?,?)");
        $queryAddAppointment->bindParam(1, $appointmentDate, PDO::PARAM_STR);
        $queryAddAppointment->bindParam(2, $appointmentTime, PDO::PARAM_STR);
        $queryAddAppointment->bindParam(3, $productId      , PDO::PARAM_INT);
        $queryAddAppointment->bindParam(4, $costumerId     , PDO::PARAM_INT);
        $queryAddAppointment->bindParam(5, $appointmentDetails, PDO::PARAM_STR);
        $appointmentAddResult = $queryAddAppointment->execute();

        if($appointmentAddResult){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevunuz başarıyla alınmıştır";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Randevunuz eklenirken hata oluştu. Tekrar deneyiniz";
        }

        return $response;
    }


    public function addSeansAppointment($appointmentModel, $seansNumber){
        $response = array();

        $appointmentDate    = $appointmentModel->getAppointmentDate();
        $appointmentTime    = $appointmentModel->getAppointmentTime();
        $productId          = $appointmentModel->getServiceId();
        $costumerId         = $appointmentModel->getCostumerId();
        $appointmentDetails = $appointmentModel->getAppointmentDetail();

        $installmentTransactions  = new InstallmentTransactions();
        $appointmentDates = $installmentTransactions->appointmentSeansDate($appointmentDate);

        $queryAddAppointment = $this->baglanti->prepare("INSERT INTO randevular(randevu_tarih, randevu_saat, hizmet_id, musteri_id, randevu_detay)
                                                         VALUES(?,?,?,?,?)");

        $number = 1;
        for($i = 0; $i < $seansNumber; $i++){
            $details = $number . " numaralı seansa ait randevu. Detaylar : " . $appointmentDetails;
            $number++;
            $queryAddAppointment->bindParam(1, $appointmentDates[$i], PDO::PARAM_STR);
            $queryAddAppointment->bindParam(2, $appointmentTime, PDO::PARAM_STR);
            $queryAddAppointment->bindParam(3, $productId      , PDO::PARAM_INT);
            $queryAddAppointment->bindParam(4, $costumerId     , PDO::PARAM_INT);
            $queryAddAppointment->bindParam(5, $details        , PDO::PARAM_STR);
            $queryAddAppointment->execute();
        }
        $response["success"] = parent::BASARILI;
        $response["message"] = "Randevunuz başarıyla alınmıştır";

        return $response;
    }

    public function pastAppointment(){
        $response = array();

        $nowDate = date("Y-m-d");

        $appointmentsToday = $this->baglanti->prepare("SELECT * FROM appointmenttakers where appointmenttakers.randevu_tarih < :nowDate");
        $appointmentsToday->bindValue(":nowDate",$nowDate,PDO::PARAM_STR);
        $appointmentsToday->execute();
        $appointmentsTodayResponse = $appointmentsToday->fetchAll(PDO::FETCH_ASSOC);

        if($appointmentsTodayResponse){
            $response["appointments"] = array();

            foreach($appointmentsTodayResponse as $appointment){
                $appointmentModel = $this->addAppointmentTodayModel($appointment);
                array_push($response["appointments"],$appointmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevular başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function upComingAppointment(){
        $response = array();

        $nowDate = date("Y-m-d");

        $appointmentsToday = $this->baglanti->prepare("SELECT * FROM appointmenttakers where appointmenttakers.randevu_tarih >= :nowDate ORDER BY randevu_id DESC");
        $appointmentsToday->bindValue(":nowDate",$nowDate,PDO::PARAM_STR);
        $appointmentsToday->execute();
        $appointmentsTodayResponse = $appointmentsToday->fetchAll(PDO::FETCH_ASSOC);

        if($appointmentsTodayResponse){
            $response["appointments"] = array();

            foreach($appointmentsTodayResponse as $appointment){
                $appointmentModel = $this->addAppointmentTodayModel($appointment);
                array_push($response["appointments"],$appointmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevular başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Randevu bilgisi bulunamadı";
        }

        return $response;
    }


    public function fetchAppointments(){
        $response = array();


        $appointmentsToday = $this->baglanti->prepare("SELECT * FROM appointmenttakers ORDER BY randevu_tarih DESC");
        $appointmentsToday->execute();
        $appointmentsTodayResponse = $appointmentsToday->fetchAll(PDO::FETCH_ASSOC);

        if($appointmentsTodayResponse){
            $response["appointments"] = array();

            foreach($appointmentsTodayResponse as $appointment){
                $appointmentModel = $this->addAppointmentTodayModel($appointment);
                array_push($response["appointments"],$appointmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevular başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchAppointmentsTodayShow($appointmentDate){
        $response = array();

        $appointmentsToday = $this->baglanti->prepare("SELECT * FROM appointmenttakers WHERE randevu_tarih = :randevu_tarih AND durum_id = 1 ORDER BY randevu_saat ASC");
        $appointmentsToday->bindValue(":randevu_tarih", $appointmentDate, PDO::PARAM_STR);
        $appointmentsToday->execute();
        $appointmentsTodayResponse = $appointmentsToday->fetchAll(PDO::FETCH_ASSOC);

        if($appointmentsTodayResponse){
            $response["appointments"] = array();

            foreach($appointmentsTodayResponse as $appointment){
                $appointmentModel = $this->addAppointmentTodayModel($appointment);
                array_push($response["appointments"],$appointmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Bugüne ait randevular başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Bugüne ait randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchAppointmentsToday($appointmentDate){
        $response = array();

        $appointmentsToday = $this->baglanti->prepare("SELECT * FROM appointmenttakers WHERE randevu_tarih = :randevu_tarih ORDER BY randevu_saat ASC");
        $appointmentsToday->bindValue(":randevu_tarih", $appointmentDate, PDO::PARAM_STR);
        $appointmentsToday->execute();
        $appointmentsTodayResponse = $appointmentsToday->fetchAll(PDO::FETCH_ASSOC);

        if($appointmentsTodayResponse){
            $response["appointments"] = array();

            foreach($appointmentsTodayResponse as $appointment){
                $appointmentModel = $this->addAppointmentTodayModel($appointment);
                array_push($response["appointments"],$appointmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Bugüne ait randevular başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Bugüne ait randevu bilgisi bulunamadı";
        }

        return $response;
    }

    public function deleteAppointment($appointment_id, $appointmentDate, $appointmentTime, $serviceId){
        $response = array();

        $deleteAppointment = $this->baglanti->prepare("DELETE FROM randevular  WHERE randevu_id = :randevu_id");
        $deleteAppointment->bindValue(":randevu_id", $appointment_id, PDO::PARAM_INT);
        $deleteAppointment->execute();

        if($deleteAppointment->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Randevu başarıyla iptal edildi";

        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Randevu iptal edilemedi";
        }

        return $response;
    }

    public function numberOfAppointments(){
        $todayNumberOfAppointments = $this->baglanti->prepare("SELECT COUNT(*) as randevu_sayisi FROM appointmenttakers WHERE randevu_tarih = :randevu_tarih");
        $todayNumberOfAppointments->bindValue("randevu_tarih",date("Y-m-d"),PDO::PARAM_STR);
        $todayNumberOfAppointments->execute();
        $todayNumberOfAppointmentsResponse = $todayNumberOfAppointments->fetch(PDO::FETCH_OBJ);



        if($todayNumberOfAppointmentsResponse){
            $totalPaid = $todayNumberOfAppointmentsResponse->randevu_sayisi;
        }
        return $totalPaid;
    }

    public function addAppointmentTodayModel($appointmentToday){
        $appointmentTodayModel = new AppointmentModel();

        $appointmentTodayModel->setAppointmentId($appointmentToday["randevu_id"]);
        $appointmentTodayModel->setAppointmentDate($appointmentToday["randevu_tarih"]);
        $appointmentTodayModel->setAppointmentTime($appointmentToday["randevu_saat"]);
        $appointmentTodayModel->setStatusId($appointmentToday["durum_id"]);
        $appointmentTodayModel->setServiceId($appointmentToday["hizmet_id"]);
        $appointmentTodayModel->setServiceName($appointmentToday["hizmet_adi"]);
        $appointmentTodayModel->setServiceTime($appointmentToday["tahmini_hizmet_suresi"]);
        $appointmentTodayModel->setCostumerId($appointmentToday["musteri_id"]);
        $appointmentTodayModel->setCostumerTc($appointmentToday["musteri_tc"]);
        $appointmentTodayModel->setCostumerName($appointmentToday["musteri_ad"]);
        $appointmentTodayModel->setCostumerSurname($appointmentToday["musteri_soyad"]);
        $appointmentTodayModel->setAppointmentDetail($appointmentToday["randevu_detay"]);
        $appointmentTodayModel->setCostumerPhone($appointmentToday["telefon"]);

        return $appointmentTodayModel->toString();

    }



    public function addAppointmentModel($appointment){
        $appointmentModel = new AppointmentModel();

        $appointmentModel->setAppointmentId($appointment["randevu_id"]);
        $appointmentModel->setAppointmentDate($appointment["randevu_tarih"]);
        $appointmentModel->setAppointmentTime($appointment["randevu_saat"]);
        $appointmentModel->setStatusId($appointment["durum_id"]);
        $appointmentModel->setServiceId($appointment["hizmet_id"]);
        $appointmentModel->setServiceName($appointment["hizmet_adi"]);
        $appointmentModel->setServiceTime($appointment["tahmini_hizmet_suresi"]);
        $appointmentModel->setServicePreviewUrl($appointment["hizmet_onizleme_url"]);
        $appointmentModel->setAppointmentDetail($appointment["randevu_detay"]);

        return $appointmentModel->toString();
    }

    public function __destruct(){
        parent::__destruct();
    }
}



?>
