<?php

require_once(__DIR__ . '/CampaignsService.php');
require_once(__DIR__ . '/CampaignModel.php');
require_once(__DIR__ . '/../Veritabani.php');

class CampaignsServiceImp extends Veritabani implements CampaignsService{

    public function __construct(){
        parent::__construct();
    }

    public function fetchCampaigns(){
        $response = array();

        $campaignQuery = $this->baglanti->query("SELECT * FROM kampanyalar");
        $campaignQuery->execute();
        $campaingResponse = $campaignQuery->fetchAll(PDO::FETCH_ASSOC);

        if($campaingResponse){
            $response["campaigns"] = array();

            foreach($campaingResponse as $campaign){
                $campaignList = $this->addCampaignModel($campaign);
                array_push($response["campaigns"],$campaignList);
            }

            $response["success"]  = parent::BASARILI;
            $response["message"]  = "Kampanyalar başarıyla alındı";
        }else{
            $response["success"]  = parent::BOS;
            $response["message"]  = "Kampanyalar ait bilgi bulunamadı";
        }

        return $response;
    }


    public function getCampaignDetails($campaignId){
        $response = array();

        $campaignQuery = $this->baglanti->prepare("SELECT * FROM kampanyalar WHERE kampanya_id = :campaign_id");
        $campaignQuery->bindValue(":campaign_id", $campaignId, PDO::PARAM_INT);
        $campaignQuery->execute();
        $campaingResponse = $campaignQuery->fetchAll(PDO::FETCH_ASSOC);

        if($campaingResponse){
            $response["campaign"] = $this->addCampaignModel($campaingResponse[0]);
            $response["success"]  = parent::BASARILI;
            $response["message"]  = "Kampanyalar başarıyla alındı";
        }else{
            $response["success"]  = parent::BOS;
            $response["message"]  = "Kampanyalar ait bilgi bulunamadı";
        }

        return $response;
    }

    public function addCampaign($campaignTitle, $campaignContent, $campaignImage){
        $response = array();

        $campaignAdd = $this->baglanti->prepare("INSERT INTO kampanyalar(kampanya_resmi, kampanya_basligi, kampanya_icerigi) 
                                                        VALUES (?, ?, ?)");
        $campaignAdd->bindParam(1, $campaignImage  , PDO::PARAM_STR);
        $campaignAdd->bindParam(2, $campaignTitle  , PDO::PARAM_STR);
        $campaignAdd->bindParam(3, $campaignContent, PDO::PARAM_STR);
        $campaignResponse = $campaignAdd->execute();

        if($campaignResponse){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Kampanya başarıyla eklendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Kampanya eklenemedi";
        }

        return $response;
    }

    public function updateCampaign($campaign_id, $campaignTitle, $campaignContent, $campaignImage){
        $response = array();

        $campaignAdd = $this->baglanti->prepare("UPDATE kampanyalar SET kampanya_basligi = :kampanya_basligi , 
                                                                        kampanya_icerigi = :kampanya_icerigi, kampanya_resmi = :kampanya_resmi
                                                                         WHERE kampanya_id = :kampanya_id");
        $campaignAdd->bindValue(":kampanya_basligi", $campaignTitle  , PDO::PARAM_STR);
        $campaignAdd->bindValue(":kampanya_icerigi", $campaignContent, PDO::PARAM_STR);
        $campaignAdd->bindValue(":kampanya_resmi"  , $campaignImage  , PDO::PARAM_STR);
        $campaignAdd->bindValue(":kampanya_id"     , $campaign_id    , PDO::PARAM_INT);
        $campaignResponse = $campaignAdd->execute();

        if($campaignResponse){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Kampanya başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Kampanya güncellenemedi";
        }

        return $response;
    }

    public function updateCampaign2($campaign_id, $campaignTitle, $campaignContent){
        $response = array();

        $campaignAdd = $this->baglanti->prepare("UPDATE kampanyalar SET kampanya_basligi = :kampanya_basligi , kampanya_icerigi = :kampanya_icerigi WHERE kampanya_id = :kampanya_id");
        $campaignAdd->bindValue(":kampanya_basligi", $campaignTitle  , PDO::PARAM_STR);
        $campaignAdd->bindValue(":kampanya_icerigi", $campaignContent, PDO::PARAM_STR);
        $campaignAdd->bindValue(":kampanya_id"     , $campaign_id    , PDO::PARAM_INT);
        $campaignResponse = $campaignAdd->execute();
        

        if($campaignResponse){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Kampanya başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Kampanya güncellenemedi";
        }

        return $response;
    }

    public function deleteCampaigns($campaign_id){
        $response = array();

        $deleteCampaign = $this->baglanti->prepare("DELETE FROM kampanyalar WHERE kampanya_id = :kampanya_id");
        $deleteCampaign->bindParam(":kampanya_id", $campaign_id, PDO::PARAM_INT);
        $deleteCampaign->execute();

        if($deleteCampaign){
            $response["success"]  = parent::BASARILI;
            $response["message"]  = "Kampanya başarıyla silindi";
        }else{
            $response["success"]  = parent::BASARISIZ;
            $response["message"]  = "Kampanya silinirken hata oluştu";
        }

        return $response;

    }

    private function addCampaignModel($campaingResponse){
        $campaignModel = new CampaignModel();
        $campaignModel->setCampaignId($campaingResponse["kampanya_id"]);
        $campaignModel->setCampaignImage($campaingResponse["kampanya_resmi"]);
        $campaignModel->setCampaignTitle($campaingResponse["kampanya_basligi"]);
        $campaignModel->setCampaignContent($campaingResponse["kampanya_icerigi"]);
        return $campaignModel->toString();
    }


    public function __destruct(){
        parent::__destruct();
    }

}



?>