<?php
require_once(__DIR__ . "/InstallmentService.php");
require_once(__DIR__ . "/InstallmentModel.php");
require_once(__DIR__ . "/WillPayThisMonthModel.php");
require_once(__DIR__ . "/../payment/PaymentServiceImp.php");
require_once(__DIR__ . "/../sales/SalesServiceImp.php");
require_once(__DIR__ . "/../Veritabani.php");
require_once(__DIR__ . "/../../utility/InstallmentTransactions.php");

class InstallmentServiceImp extends Veritabani implements InstallmentService{


    public function __construct(){
        parent::__construct();
    }

    public function getInstallmentInformation($installment_id){
        $response = array();

        $installmentInformation = $this->baglanti->prepare("SELECT * FROM taksitler WHERE taksit_id = :taksit_id");
        $installmentInformation->bindValue("taksit_id",$installment_id);
        $installmentInformation->execute();
        $responseInstallment = $installmentInformation->fetch(PDO::FETCH_OBJ);

        if($responseInstallment){
            $response["installment"] = $responseInstallment;
            $response["success"]     = parent::BASARILI;
            $response["message"]     = "Taksit bilgisi başarıyla alındı";
        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Taksit bilgisi bulunamadı";
        }

        return $response;
    }
    
    public function addInstallment($sales_id, $feePayable, $installment_numbers){
        $installmentTransactions  = new InstallmentTransactions();

        $installmentDates = $installmentTransactions->prepareInstallmentDate(date("d-m-Y"));
        $installments     = $installmentTransactions->calculateInstallment($feePayable, $installment_numbers);

        $firstInstallment = $installments["firstInstallment"];
        $installment      = $installments["installment"];

        $queryAddInstallment = $this->baglanti->prepare("INSERT INTO taksitler(odenecek_taksit, odenecek_ucret, odenecek_tarih, satis_id)
                                                                     VALUES (?, ?, ?, ?)");

        for($i = 0; $i < $installment_numbers; $i++){
            $installmentPayable = $i + 1;
            if($i == 0){
                $queryAddInstallment->bindParam(1, $installmentPayable  , PDO::PARAM_INT);
                $queryAddInstallment->bindParam(2, $firstInstallment    , PDO::PARAM_INT);
                $queryAddInstallment->bindParam(3, $installmentDates[$i], PDO::PARAM_STR);
                $queryAddInstallment->bindParam(4, $sales_id            , PDO::PARAM_STR);
            }else{
                $queryAddInstallment->bindParam(1, $installmentPayable  , PDO::PARAM_INT);
                $queryAddInstallment->bindParam(2, $installment         , PDO::PARAM_INT);
                $queryAddInstallment->bindParam(3, $installmentDates[$i], PDO::PARAM_STR);
                $queryAddInstallment->bindParam(4, $sales_id            , PDO::PARAM_STR);
            }
            $queryAddInstallment->execute();
        }
        
    }

    public function webFetchInstallmentById($sales_id){
        $response = array();

        $installments = $this->baglanti->prepare("SELECT 
                                                taksit.taksit_id, taksit.odenecek_taksit,
                                                taksit.odenen_ucret, taksit.odenecek_ucret as toplamTaksitFiyatı,
                                                (taksit.odenecek_ucret - taksit.odenen_ucret) as kalanTaksitMiktari, taksit.odenecek_tarih,
                                                taksit.satis_id, taksit.taksit_durum_id,
                                                taksit_durum.taksit_durum
                                               FROM taksitler as taksit
                                               INNER JOIN taksit_durum as taksit_durum ON taksit_durum.taksit_durum_id = taksit.taksit_durum_id
                                               WHERE taksit.satis_id = :satis_id
                                               ORDER BY taksit.odenecek_taksit ASC");
        $installments->bindValue(":satis_id", $sales_id);
        $installments->execute();
        $installmentsResponse = $installments->fetchAll(PDO::FETCH_OBJ);

        if($installmentsResponse){
            $response["installments"] = $installmentsResponse;
            $response["success"] = parent::BASARILI;
            $response["message"] = "Taksitler başarıyla çekildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Taksit bilgisi bulunamadı";
        }

        return $response;
    }

    public function installmentDateCheck(){

        $allInstallment = $this->baglanti->query("SELECT taksitler.taksit_id, taksitler.odenecek_ucret, taksitler.odenen_ucret, 
                                                             taksitler.odenecek_tarih, kullanicilar.ad, kullanicilar.soyad  FROM taksitler 
                                                            INNER JOIN satislar ON satislar.satis_id = taksitler.satis_id
                                                            INNER JOIN kullanicilar ON kullanicilar.musteri_id = satislar.musteri_id
                                                            WHERE taksit_durum_id = 1")->fetchAll(PDO::FETCH_OBJ);
        foreach($allInstallment as $installment){
            $installmentId = $installment->taksit_id;
            $feePayable = $installment->odenecek_ucret;
            $feePaid    = $installment->odenen_ucret;
            $payDate = strtotime($installment->odenecek_tarih);
            $nowDate = strtotime(date("Y-m-d"));
            if($nowDate > $payDate){
                $this->baglanti->exec("UPDATE taksitler SET taksit_durum_id = 3 WHERE taksit_id = $installmentId");
            }
        }

        $gecmisTaksitler = $this->baglanti->query("SELECT taksitler.taksit_id, taksitler.odenecek_ucret, taksitler.odenen_ucret, 
                                                             taksitler.odenecek_tarih, kullanicilar.ad, kullanicilar.soyad  FROM taksitler 
                                                            INNER JOIN satislar ON satislar.satis_id = taksitler.satis_id
                                                            INNER JOIN kullanicilar ON kullanicilar.musteri_id = satislar.musteri_id
                                                            WHERE taksit_durum_id = 3")->fetchAll(PDO::FETCH_OBJ);
        foreach($gecmisTaksitler as $installment){
            $installmentId = $installment->taksit_id;
            $feePayable = $installment->odenecek_ucret;
            $feePaid    = $installment->odenen_ucret;
            $payDate = strtotime($installment->odenecek_tarih . " +1 month");
            $nowDate = strtotime(date("Y-m-d"));
            if($nowDate > $payDate){
                $information =  $installment->ad . " " . $installment->soyad . " adlı kişinin " . date("d.m.Y",strtotime($installment->odenecek_tarih)) . " Ödeme tarihli " . ($feePayable - $feePaid) . "₺ taksit tutarı gecikmiştir";
                $bildirimSorgu = $this->baglanti->prepare("SELECT * FROM bilgilendirme WHERE taksit_id = :taksit_id");
                $bildirimSorgu->bindValue("taksit_id",$installmentId);
                $bildirimSorgu->execute();
                $bildirimCevap = $bildirimSorgu->fetchAll(PDO::FETCH_OBJ);
                if(empty($bildirimCevap)){
                    $this->baglanti->exec("INSERT INTO bilgilendirme (bilgilendirme,taksit_id) VALUES('$information','$installmentId')");
                }
            }
        }

        $bilgilendirmeKontrol = $this->baglanti->query("SELECT * FROM bilgilendirme 
                                                                 LEFT JOIN taksitler ON taksitler.taksit_id = bilgilendirme.taksit_id
                                                                 WHERE taksitler.odenecek_ucret = taksitler.odenen_ucret")->fetchAll(PDO::FETCH_OBJ);

        if(!empty($bilgilendirmeKontrol)){
            foreach ($bilgilendirmeKontrol as $bilgilendirme){
                $bilgilendirmeId = $bilgilendirme->bilgilendirme_id;
                $bilgilendirmeGuncelleme = $this->baglanti->prepare("DELETE FROM bilgilendirme WHERE bilgilendirme_id = :bilgilendirme_id");
                $bilgilendirmeGuncelleme->bindValue(":bilgilendirme_id",$bilgilendirmeId);
                $bilgilendirmeGuncelleme->execute();
            }
        }

    }


    public function pastDueInstallments(){
        $response = array();

        $pastInstallment = $this->baglanti->query("SELECT 
                                                kullanicilar.ad, kullanicilar.soyad, kullanicilar.kullanici_tc,
                                                (taksit.odenecek_ucret - taksit.odenen_ucret) as odenecek_ucret, taksit.odenecek_tarih,
                                                 taksit.taksit_durum_id, taksit_durum.taksit_durum
                                               FROM taksitler as taksit
                                               INNER JOIN satislar ON satislar.satis_id = taksit.satis_id
                                               INNER JOIN kullanicilar ON kullanicilar.musteri_id = satislar.musteri_id
                                               INNER JOIN taksit_durum as taksit_durum ON taksit_durum.taksit_durum_id = taksit.taksit_durum_id
                                               WHERE  taksit.taksit_durum_id = 3")->fetchAll(PDO::FETCH_OBJ);
        if(!empty($pastInstallment)){
            $response["installments"] = $pastInstallment;

            $response["success"] = parent::BASARILI;
            $response["message"] = "Taksitler başarıyla çekildi";
        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Taksit bilgisi bulunamadı";
        }

        return $response;
    }

    public function pastDueInstallmentsNumber(){
        $pastInstallment = $this->baglanti->query("SELECT COUNT(*) as pastInstallmentCount FROM taksitler WHERE  taksit_durum_id = 3")->fetch(PDO::FETCH_OBJ);

        return $pastInstallment->pastInstallmentCount;
    }


    public function fetchInstallmentById($sales_id){
        $response = array();

        $installments = $this->baglanti->prepare("SELECT 
                                                taksit.taksit_id, taksit.odenecek_taksit,
                                                (taksit.odenecek_ucret - taksit.odenen_ucret) as odenecek_ucret, taksit.odenecek_tarih,
                                                taksit.satis_id, taksit.taksit_durum_id,
                                                taksit_durum.taksit_durum
                                               FROM taksitler as taksit
                                               INNER JOIN taksit_durum as taksit_durum ON taksit_durum.taksit_durum_id = taksit.taksit_durum_id
                                               WHERE taksit.satis_id = :satis_id AND taksit.taksit_durum_id != 2");
        $installments->bindValue(":satis_id", $sales_id, PDO::PARAM_INT);
        $installments->execute();
        $installmentsResponse = $installments->fetchAll(PDO::FETCH_ASSOC);

        if($installmentsResponse){
            $response["installments"] = array();

            foreach($installmentsResponse as $installment){
                $installmentModel = $this->addInstallmentModel($installment);
                array_push($response["installments"], $installmentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Taksitler başarıyla çekildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Taksit bilgisi bulunamadı";
        }

        return $response;
    }

    public function payInstallment2($calisanId, $satisId, $taksitId, $odenenUcret, $odemeTip = 1){
        $response = array();
        $odendi = 2;

        $taksitBilgileri = $this->baglanti->prepare("SELECT * FROM taksitler WHERE taksit_id >= :taksit_id  AND satis_id = :satis_id");
        $taksitBilgileri->bindValue(":taksit_id",$taksitId);
        $taksitBilgileri->bindValue(":satis_id",$satisId);
        $taksitBilgileri->execute();
        $taksitlerCevap = $taksitBilgileri->fetchAll(PDO::FETCH_OBJ);

        $kalanUcret = $odenenUcret;

        foreach ($taksitlerCevap as $taksit){
            $guncelTaksitId = $taksit->taksit_id;
            $odenecekUcret = $taksit->odenecek_ucret - $taksit->odenen_ucret;

            if($odenecekUcret >= $kalanUcret){
                $odenenToplamUcret = $taksit->odenen_ucret + $kalanUcret;

                if($odenecekUcret == $kalanUcret){
                    $taksitGuncelleme = $this->baglanti->prepare("UPDATE taksitler SET odenen_ucret = :odenen_ucret, taksit_durum_id = :taksit_durum_id WHERE taksit_id = :taksit_id");
                    $taksitGuncelleme->bindValue("odenen_ucret",$odenenToplamUcret,PDO::PARAM_STR);
                    $taksitGuncelleme->bindValue("taksit_durum_id",$odendi);
                    $taksitGuncelleme->bindValue("taksit_id",$guncelTaksitId);
                    $taksitGuncelleme->execute();
                    $bildirimSilme = $this->baglanti->prepare("DELETE FROM bilgilendirme WHERE taksit_id = :taksit_id");
                    $bildirimSilme->bindValue("taksit_id",$guncelTaksitId);
                    $bildirimSilme->execute();
                }else{
                    $taksitGuncelleme = $this->baglanti->prepare("UPDATE taksitler SET odenen_ucret = :odenen_ucret WHERE taksit_id = :taksit_id");
                    $taksitGuncelleme->bindValue("odenen_ucret",$odenenToplamUcret,PDO::PARAM_STR);
                    $taksitGuncelleme->bindValue("taksit_id",$guncelTaksitId);
                    $taksitGuncelleme->execute();
                }
                break;
            }else{
                $kalanUcret = $kalanUcret - $odenecekUcret;

                $taksitGuncelleme = $this->baglanti->prepare("UPDATE taksitler SET odenen_ucret = :odenen_ucret, taksit_durum_id = :taksit_durum_id WHERE taksit_id = :taksit_id");
                $taksitGuncelleme->bindValue("odenen_ucret",$taksit->odenecek_ucret,PDO::PARAM_STR);
                $taksitGuncelleme->bindValue("taksit_durum_id",$odendi);
                $taksitGuncelleme->bindValue("taksit_id",$guncelTaksitId);
                $taksitGuncelleme->execute();
                $bildirimSilme = $this->baglanti->prepare("DELETE FROM bilgilendirme WHERE taksit_id = :taksit_id");
                $bildirimSilme->bindValue("taksit_id",$guncelTaksitId);
                $bildirimSilme->execute();
            }
        }

        $paymentModel = new PaymentModel();

        $paymentModel->setSalesId($satisId);
        $paymentModel->setPaymentDate(date("Y-m-d"));
        $paymentModel->setReceivedFee($odenenUcret);
        $paymentModel->setEmployeeId($calisanId);
        $paymentModel->setPaymentTypeId($odemeTip);

        if($taksitGuncelleme->rowCount() > 0){

            $this->addPayment($paymentModel);
            $this->editPaidFee($paymentModel);


            $response["success"] = parent::BASARILI;
            $response["message"] = "Taksit ödemesi başarıyla yapıldı";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Taksit odeme işlemi yapılamadı";
        }

        return $response;
    }

    public function payInstallment($employee_id, $installment_id, $feePaid, $payment_type_id = 1){
        $response = array();
        $HAS_BEEN_PAID = 2;

        $installmentInformation = $this->baglanti->prepare("SELECT
                                                        taksit.odenecek_ucret, taksit.satis_id, taksit.odenen_ucret
                                                     FROM taksitler as taksit WHERE taksit.taksit_id = :taksit_id");
        $installmentInformation->bindValue(":taksit_id", $installment_id, PDO::PARAM_INT);
        $installmentInformation->execute();
        $installmentInformationResponse = $installmentInformation->fetch(PDO::FETCH_ASSOC);

        $sales_id           = $installmentInformationResponse["satis_id"];
        $feeReceived        = $installmentInformationResponse["odenecek_ucret"];
        $installmentFeePaid = $installmentInformationResponse["odenen_ucret"];

        $paymentModel = new PaymentModel();

        $paymentModel->setSalesId($sales_id);
        $paymentModel->setPaymentDate(date("Y-m-d"));
        $paymentModel->setReceivedFee($feePaid);
        $paymentModel->setEmployeeId($employee_id);
        $paymentModel->setPaymentTypeId($payment_type_id);

        $totalFeePaid = $installmentFeePaid + $feePaid;

        if($feeReceived == $totalFeePaid){
            $installmentPayment  = $this->baglanti->prepare("UPDATE taksitler as taksit
                                                 SET odenen_ucret = :odenen_ucret ,taksit.taksit_durum_id = :taksit_durum_id
                                                 WHERE taksit.taksit_id = :taksit_id");
            $installmentPayment->bindValue(":odenen_ucret"   , $totalFeePaid);
            $installmentPayment->bindValue(":taksit_durum_id", $HAS_BEEN_PAID);
            $installmentPayment->bindValue(":taksit_id"      , $installment_id);
            $this->baglanti->exec("DELETE FROM bilgilendirme WHERE taksit_id = $installment_id");
        }else{
            $installmentPayment  = $this->baglanti->prepare("UPDATE taksitler as taksit
                                                 SET odenen_ucret = :odenen_ucret
                                                 WHERE taksit.taksit_id = :taksit_id");
            $installmentPayment->bindValue(":odenen_ucret"   , $totalFeePaid);
            $installmentPayment->bindValue(":taksit_id"      , $installment_id);
        }
        $installmentPayment->execute();

        if($installmentPayment->rowCount() > 0){

            $this->addPayment($paymentModel);
            $this->editPaidFee($paymentModel);


            $response["success"] = parent::BASARILI;
            $response["message"] = "Taksit ödemesi başarıyla yapıldı";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Taksit odeme işlemi yapılamadı";
        }

        return $response;
    }

/*    public function payInstallment($employee_id, $installment_id, $feePaid, $payment_type_id = 1){
        $response = array();
        $HAS_BEEN_PAID = 2;

        $installmentInformation = $this->baglanti->prepare("SELECT
                                                        taksit.odenecek_ucret, taksit.satis_id, taksit.odenen_ucret
                                                     FROM taksitler as taksit WHERE taksit.taksit_id = :taksit_id");
        $installmentInformation->bindValue(":taksit_id", $installment_id, PDO::PARAM_INT);
        $installmentInformation->execute();
        $installmentInformationResponse = $installmentInformation->fetch(PDO::FETCH_ASSOC);

        $sales_id           = $installmentInformationResponse["satis_id"];
        $feeReceived        = $installmentInformationResponse["odenecek_ucret"];
        $installmentFeePaid = $installmentInformationResponse["odenen_ucret"];
        $paymentModel = new PaymentModel();

        $paymentModel->setSalesId($sales_id);
        $paymentModel->setPaymentDate(date("Y-m-d"));
        $paymentModel->setReceivedFee($feePaid);
        $paymentModel->setEmployeeId($employee_id);
        $paymentModel->setPaymentTypeId($payment_type_id);

        $totalPaid = $feeReceived - $installmentFeePaid;
        if($totalPaid >= $feePaid){

            $totalFeePaid = $installmentFeePaid + $feePaid;

            if($feeReceived == $totalFeePaid){
                $installmentPayment  = $this->baglanti->prepare("UPDATE taksitler as taksit
                                                 SET odenen_ucret = :odenen_ucret ,taksit.taksit_durum_id = :taksit_durum_id
                                                 WHERE taksit.taksit_id = :taksit_id");
                $installmentPayment->bindValue(":odenen_ucret"   , $totalFeePaid);
                $installmentPayment->bindValue(":taksit_durum_id", $HAS_BEEN_PAID);
                $installmentPayment->bindValue(":taksit_id"      , $installment_id);
                $deneme = $this->baglanti->prepare("DELETE FROM bilgilendirme WHERE taksit_id = :taksit_id");
                $deneme->bindValue(":taksit_id",$installment_id);
                $deneme->execute();
            }else{
                $installmentPayment  = $this->baglanti->prepare("UPDATE taksitler as taksit
                                                 SET odenen_ucret = :odenen_ucret
                                                 WHERE taksit.taksit_id = :taksit_id");
                $installmentPayment->bindValue(":odenen_ucret"   , $totalPaid);
                $installmentPayment->bindValue(":taksit_id"      , $installment_id);
            }
            $installmentPayment->execute();

            if($installmentPayment->rowCount() > 0){

                $this->addPayment($paymentModel);
                $this->editPaidFee($paymentModel);


                $response["success"] = parent::BASARILI;
                $response["message"] = "Taksit ödemesi başarıyla yapıldı";
            }else{
                $response["success"] = parent::BASARISIZ;
                $response["message"] = "Taksit odeme işlemi yapılamadı";
            }
        }else{

            $endFeePaid = $feePaid - $feeReceived;

            $installmentPayment1  = $this->baglanti->prepare("UPDATE taksitler as taksit
                                                 SET odenen_ucret = :odenen_ucret ,taksit.taksit_durum_id = :taksit_durum_id
                                                 WHERE taksit.taksit_id = :taksit_id");
            $installmentPayment1->bindValue(":odenen_ucret"   , $feeReceived);
            $installmentPayment1->bindValue(":taksit_durum_id", $HAS_BEEN_PAID);
            $installmentPayment1->bindValue(":taksit_id"      , $installment_id);
            $installmentPayment1->execute();
            $deneme = $this->baglanti->prepare("DELETE FROM bilgilendirme WHERE taksit_id = :taksit_id");
            $deneme->bindValue(":taksit_id",$installment_id);
            $deneme->execute();

            $id = $installment_id+ 1;
            $installmentInfo = $this->baglanti->query("SELECT * FROM taksitler WHERE taksit_id = $id")->fetch(PDO::FETCH_OBJ);


            $kalanOdemeTaksit = ($installmentInfo->odenecek_ucret - $installmentInfo->odenen_ucret);

            if($kalanOdemeTaksit > ($endFeePaid - 1)){
                $installmentPayment  = $this->baglanti->prepare("UPDATE taksitler as taksit
                                                 SET odenen_ucret = :odenen_ucret ,taksit.taksit_durum_id = :taksit_durum_id
                                                 WHERE taksit.taksit_id = :taksit_id");
                $installmentPayment->bindValue(":odenen_ucret"   , $installmentInfo->odenecek_ucret);
                $installmentPayment->bindValue(":taksit_durum_id", $HAS_BEEN_PAID);
                $installmentPayment->bindValue(":taksit_id"      , $id);
                $deneme = $this->baglanti->prepare("DELETE FROM bilgilendirme WHERE taksit_id = :taksit_id");
                $deneme->bindValue("taksit_id",$id);
                $deneme->execute();
                $installmentPayment->execute();
            }else{
                $installmentPayment2  = $this->baglanti->prepare("UPDATE taksitler as taksit
                                                 SET odenen_ucret = :odenen_ucret
                                                 WHERE taksit.taksit_id = :taksit_id");
                $installmentPayment2->bindValue(":odenen_ucret"   , $endFeePaid);
                $installmentPayment2->bindValue(":taksit_id"      , $id);
                $installmentPayment2->execute();
            }

            if($installmentPayment->rowCount() > 0){
                $this->addPayment($paymentModel);
                $this->editPaidFee($paymentModel);

                $response["success"] = parent::BASARILI;
                $response["message"] = "Taksit ödemesi başarıyla yapıldı";
            }else{
                $response["success"] = parent::BASARISIZ;
                $response["message"] = "Taksit odeme işlemi yapılamadı";
            }
        }

        return $response;
    }*/

    public function queryWillPayThisMonth(){
        $response = array();

        $queryWillPayThisMonth = $this->baglanti->query("SELECT * FROM willpaythismonth");
        $queryWillPayThisMonth->execute();
        $responseQueryWillPayThisMonth = $queryWillPayThisMonth->fetchAll(PDO::FETCH_ASSOC);

        if($responseQueryWillPayThisMonth){
            $response["willPayThisMonth"] = array();

            foreach($responseQueryWillPayThisMonth as $willPayThisMonth){
                $willPayThisMonthModel = $this->addWillPayThisMonth($willPayThisMonth);
                array_push($response["willPayThisMonth"], $willPayThisMonthModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Bu ay ödeme yapıcak müşteri bilgileri başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Bu ödeme yapıcak müşteri bilgisi bulunamadı";
        }

        return $response;
    }


    private function addPayment($paymentModel){
        $paymentService = new PaymentServiceImp();

        $paymentService->addPayment($paymentModel);
    }

    private function editPaidFee($paymentModel){
        $sales_id    = $paymentModel->getSalesId();
        $receivedFee = $paymentModel->getReceivedFee();

        $salesService = new SalesServiceImp();

        $salesService->updateReceivedFee($sales_id, $receivedFee);
    }

    public function addInstallmentModel($installment){
        $installmentModel = new InstallmentModel();

        $installmentModel->setInstallmentId($installment["taksit_id"]);
        $installmentModel->setInstallmentPayable($installment["odenecek_taksit"]);
        $installmentModel->setFeePayable($installment["odenecek_ucret"]);
        $installmentModel->setDueDate($installment["odenecek_tarih"]);
        $installmentModel->setSalesId($installment["satis_id"]);
        $installmentModel->setInstallmentStatusId($installment["taksit_durum_id"]);
        $installmentModel->setInstallmentStatus($installment["taksit_durum"]);
        
        return $installmentModel->toString();
    }

    public function addWillPayThisMonth($queryWillPayThisMonth){
        $willPayThisMonth = new WillPayThisMonthModel();

        $willPayThisMonth->setCostumerName($queryWillPayThisMonth["ad"]);
        $willPayThisMonth->setCostumerSurname($queryWillPayThisMonth["soyad"]);
        $willPayThisMonth->setCostumerPhone($queryWillPayThisMonth["telefon"]);
        $willPayThisMonth->setNumberOfInstallment($queryWillPayThisMonth["taksit_sayi"]);
        $willPayThisMonth->setInstallmentStatus($queryWillPayThisMonth["taksit_durum_id"]);
        $willPayThisMonth->setPaymentTime($queryWillPayThisMonth["odenecek_tarih"]);
        $willPayThisMonth->setFeePayable($queryWillPayThisMonth["odenecek_ucret"]);
        $willPayThisMonth->setServiceName($queryWillPayThisMonth["hizmet_adi"]);
        
        return $willPayThisMonth->toString();
    }


    public function __destruct(){
        parent::__destruct();
    }


}

?>