<?php

require_once(__DIR__ . "/PaymentService.php");
require_once(__DIR__ . "/PaymentModel.php");
require_once(__DIR__ . "/../installments/WillPayThisMonthModel.php");
require_once(__DIR__ .  "/../sales/SalesServiceImp.php");
require_once(__DIR__ . "/../Veritabani.php");

class PaymentServiceImp extends Veritabani implements PaymentService{

    public function __construct(){
        parent::__construct();
    }

    public function fetchPaymentsByCostumerId($costumer_id){
        $salesResponse = $this->fetchSalesByCostumerId($costumer_id);
        if($salesResponse != null){
            $response["payments"] = array();
            foreach($salesResponse as $sales){
                $sales_id    = $sales["satis_id"];
                $serviceId   = $sales["hizmet_id"];
                $serviceName = $sales["hizmet_adi"];
                $serviceTime = $sales["tahmini_hizmet_suresi"];
                $serivcePreviewUrl = $sales["hizmet_onizleme_url"];

                $queryFetchPayments = $this->baglanti->prepare("SELECT
                                                                    odeme.odeme_id, odeme.odeme_tarih,
                                                                    odeme.alinan_ucret, odeme.odeme_tur_id, tur.odeme_tur,
                                                                    calisan.calisan_id, calisan.calisan_adi, calisan.calisan_soyadi
                                                                FROM odemeler as odeme
                                                                INNER JOIN odeme_tur as tur ON tur.odeme_tur_id = odeme.odeme_tur_id
                                                                INNER JOIN calisanlar as calisan ON calisan.calisan_id = odeme.odeme_alan_id WHERE odeme.satis_id = :satis_id");

                $queryFetchPayments->bindValue(":satis_id", $sales_id, PDO::PARAM_INT);
                $queryFetchPayments->execute();
                $paymentsResponse = $queryFetchPayments->fetchAll(PDO::FETCH_ASSOC);
                if($paymentsResponse){
                    foreach($paymentsResponse as $payment){
                        $payment["hizmet_id"]             = $serviceId;
                        $payment["hizmet_adi"]            = $serviceName;
                        $payment["tahmini_hizmet_suresi"] = $serviceTime;
                        $payment["hizmet_onizleme_url"]   = $serivcePreviewUrl;
                        $paymentModel = $this->addPaymentModel($payment);
                        array_push($response["payments"],$paymentModel);
                    }
                }
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Ödeme bilgileri getirildi";
        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Ödeme bilgileri bulunamadi";
        }


            return $response;
    }

    private function fetchSalesByCostumerId($costumer_id){
        $queryFetchSalesById = $this->baglanti->prepare("SELECT
                satis.satis_id, satis.toplam_ucret,
                satis.odenen_ucret, satis.satis_detay,
                satis.taksit_sayi,
                hizmet.hizmet_id, hizmet.hizmet_adi,
                hizmet.tahmini_hizmet_suresi, hizmet.hizmet_onizleme_url,
                durum.satis_durum_id, durum.satis_durum,
                calisan.calisan_adi, calisan.calisan_soyadi,
                calisan.yetki_id, satis.satisi_yapan_id,
                musteri.musteri_telefon, musteri.musteri_id,
                musteri.musteri_ad, musteri.musteri_soyad,
                musteri.musteri_tc, musteri.musteri_dogum_tarih,
                musteri.musteri_adres, musteri.musteri_meslek,
                musteri.cinsiyet_id, cinsiyet.cinsiyet
            FROM satislar as satis
            INNER JOIN hizmetler as hizmet ON hizmet.hizmet_id = satis.hizmet_id
            INNER JOIN satis_durum as durum ON durum.satis_durum_id = satis.satis_durum_id
            INNER JOIN calisanlar as calisan ON calisan.calisan_id = satis.satisi_yapan_id
            INNER JOIN musteriler as musteri ON musteri.musteri_id = satis.musteri_id
            INNER JOIN cinsiyet ON cinsiyet.cinsiyet_id = musteri.cinsiyet_id
            WHERE satis.musteri_id = :musteri_id");
        $queryFetchSalesById->bindValue(":musteri_id", $costumer_id, PDO::PARAM_INT);
        $queryFetchSalesById->execute();
        $salesResponse = $queryFetchSalesById->fetchAll(PDO::FETCH_ASSOC);

        if($salesResponse){
            return $salesResponse;
        }else{
            return null;
        }
    }

    public function fetchAllPayment(){
        $response = array();

        $allPayment = $this->baglanti->query("SELECT
                                                        odeme.odeme_tarih, odeme.alinan_ucret, tur.odeme_tur,
                                                        calisan.ad as calisan_ad, calisan.soyad as calisan_soyad ,hizmetler.hizmet_adi, 
                                                        musteri.ad as musteri_ad, musteri.soyad as musteri_soyad, musteri.kullanici_tc
                                                        FROM odemeler as odeme
                                                        INNER JOIN odeme_tur as tur 	   ON tur.odeme_tur_id    = odeme.odeme_tur_id
                                                        INNER JOIN satislar 			   ON satislar.satis_id   = odeme.satis_id
                                                        INNER JOIN hizmetler 			   ON hizmetler.hizmet_id = satislar.hizmet_id    
                                                        INNER JOIN kullanicilar as musteri ON musteri.musteri_id  = satislar.musteri_id
                                                        INNER JOIN kullanicilar as calisan ON calisan.musteri_id  = odeme.odeme_alan_id
                                                        ORDER BY odeme.odeme_tarih DESC")->fetchAll(PDO::FETCH_OBJ);

        if(!empty($allPayment)){
            $response["payments"] = $allPayment;
            $response["success"] = parent::BASARILI;
            $response["message"] = "Ödemeler başarıyla getirildi";
        }else{
            $response["success"] = parent::BOS;
            $response["mesaj"] = "Ödeme bilgisi bulunamadı";
        }


        return $response;
    }

    public function fetchPaymentsBySaleId($sales_id){
        $response = array();

        $queryFetchPayments = $this->baglanti->prepare("SELECT
                                                            odeme.odeme_id, odeme.odeme_tarih,
                                                            odeme.alinan_ucret, odeme.odeme_tur_id, tur.odeme_tur,
                                                            calisan.calisan_id, calisan.calisan_adi, calisan.calisan_soyadi,
                                                            hizmetler.hizmet_id, hizmetler.hizmet_adi, hizmetler.tahmini_hizmet_suresi,
                                                            hizmetler.hizmet_onizleme_url
                                                        FROM odemeler as odeme
                                                        INNER JOIN odeme_tur as tur ON tur.odeme_tur_id = odeme.odeme_tur_id
                                                        INNER JOIN satislar ON satislar.satis_id        = odeme.satis_id
                                                        INNER JOIN hizmetler ON hizmetler.hizmet_id     = satislar.hizmet_id
                                                        INNER JOIN calisanlar as calisan ON calisan.calisan_id = odeme.odeme_alan_id WHERE odeme.satis_id = :satis_id");
        $queryFetchPayments->bindValue(":satis_id", $sales_id, PDO::PARAM_INT);
        $queryFetchPayments->execute();
        $paymentsResponse = $queryFetchPayments->fetchAll(PDO::FETCH_ASSOC);

        if($paymentsResponse){
            $response["payments"] = array();

            foreach($paymentsResponse as $payment){
                $paymentModel = $this->addPaymentModel($payment);
                array_push($response["payments"],$paymentModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Ödemeler başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["mesaj"] = "Ödeme bilgisi bulunamadı";
        }


        return $response;
    }

    public function fetchWhoPayDay(){
        $response = array();
        $nowDate = date("Y-m-d");
        $whoPayDay = $this->baglanti->prepare("SELECT `odemeler`.`alinan_ucret` AS `alinan_ucret`, `musteri`.`ad` AS `musteri_ad`, 
                                            `musteri`.`soyad` AS `musteri_soyad`, `calisan`.`ad` AS `calisan_adi`, `calisan`.`soyad` AS `calisan_soyad`, 
                                            `satislar`.`toplam_ucret` AS `toplam_ucret`, `odemeler`.`odeme_tur_id` AS `odeme_tur_id`,
                                            `hizmetler`.`hizmet_adi` AS `hizmet_adi`, odeme_tur.odeme_tur
                                            FROM ((((`odemeler` join `satislar` on(`satislar`.`satis_id` = `odemeler`.`satis_id`)) 
                                                join `kullanicilar` `calisan` on(`calisan`.`musteri_id` = `odemeler`.`odeme_alan_id`)) 
                                                join `kullanicilar` `musteri` on(`musteri`.`musteri_id` = `satislar`.`musteri_id`)) 
                                                join `hizmetler` on(`hizmetler`.`hizmet_id` = `satislar`.`hizmet_id`))
                                                join odeme_tur on(odeme_tur.odeme_tur_id = odemeler.odeme_tur_id)
                                                WHERE odemeler.odeme_tarih = :nowDate");
        $whoPayDay->bindValue("nowDate",$nowDate,PDO::PARAM_STR);
        $whoPayDay->execute();
        $whoPayDayResponse = $whoPayDay->fetchAll(PDO::FETCH_ASSOC);

        if($whoPayDayResponse){
            $response["whoPayDays"] = array();

            foreach($whoPayDayResponse as $whoPayDay){
                $whoPayDayModel = $this->addWhoPayDayModel($whoPayDay);
                array_push($response["whoPayDays"],$whoPayDayModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Bugüne ait ödeme bilgisi başarıyla getirildi";
        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Bugüne ait ödeme bilgisi bulunamadı";
        }

        return $response;
    }


    public function addPayment($paymentModel){
        $response = array();

        $sales_id        = $paymentModel->getSalesId();
        $payment_date    = $paymentModel->getPaymetDate();
        $received_fee    = $paymentModel->getReceivedFee();
        $employee_id     = $paymentModel->getEmployeeId();
        $payment_type_id = $paymentModel->getPaymentTypeId();

        $addPayment = $this->baglanti->prepare("INSERT INTO odemeler(satis_id, odeme_tarih, alinan_ucret, odeme_alan_id, odeme_tur_id)
                                                 VALUES (?, ?, ?, ?, ?)");
        $addPayment->bindParam(1, $sales_id        , PDO::PARAM_INT);
        $addPayment->bindParam(2, $payment_date    , PDO::PARAM_STR);
        $addPayment->bindParam(3, $received_fee    , PDO::PARAM_STR);
        $addPayment->bindParam(4, $employee_id     , PDO::PARAM_INT);
        $addPayment->bindParam(5, $payment_type_id , PDO::PARAM_INT);
        $paymentResponse = $addPayment->execute();

        if($paymentResponse){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Ödeme başarıyla alındı";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Ödeme alınamadı";
        }

        return $response;
    }

    public function cancelPayment($paymentModel){
        $response = array();

        $payment_id   = $paymentModel->getPaymentId();
        $sales_id     = $paymentModel->getSalesId();
        $received_fee = $paymentModel->getReceivedFee();


        $cancelPayment = $this->baglanti->prepare("DELETE FROM odemeler WHERE odeme_id = :odeme_id");

        $cancelPayment->bindValue(":odeme_id", $payment_id, PDO::PARAM_INT);
        $cancelPayment->execute();

        if($cancelPayment->rowCount() > 0){

            $this->reducingTheSalesFee($sales_id, $received_fee);

            $response["success"] = parent::BASARILI;
            $response["message"] = "Ödeme iptal edildi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Ödeme iptal edilemedi";
        }

        return $response;
    }

    public function totalPaid(){
        $response = array();

        $totalTodayPaid = $this->baglanti->query("SELECT SUM(alinan_ucret) as toplamAlinanUcret FROM odemeler")->fetch(PDO::FETCH_OBJ);

        if(!empty($totalTodayPaid)){
            $response["totalPaid"] = $totalTodayPaid->toplamAlinanUcret;
            $response["success"] = parent::BASARILI;
            $response["message"] = "Toplam kazanılan para çekildi";
        }else{
            $response["totalPaid"] = 0;
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Para Çekilmedi";
        }
        return $response;
    }

    public function moneyEarnedMonth (){
        $response = array();

        $totalTodayPaid = $this->baglanti->query("SELECT sum(alinan_ucret) as toplamAlinanUcret FROM odemeler WHERE odenecek")->fetch(PDO::FETCH_OBJ);

        if(!empty($totalTodayPaid)){
            $response["totalPaid"] = $totalTodayPaid->toplamAlinanUcret;
            $response["success"] = parent::BASARILI;
            $response["message"] = "Toplam kazanılan para çekildi";
        }else{
            $response["totalPaid"] = 0;
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Para Çekilmedi";
        }
        return $response;
    }


    public function totalWagePaidToday(){
        $nowDate = date("Y-m-d");
        $totalTodayPaid = $this->baglanti->prepare("SELECT SUM(alinan_ucret) as toplamAlinanUcret, COUNT(*) as counts FROM odemeler WHERE odeme_tarih = :odeme_tarih");
        $totalTodayPaid->bindValue("odeme_tarih",$nowDate, PDO::PARAM_STR);
        $totalTodayPaid->execute();
        $response = $totalTodayPaid->fetch(PDO::FETCH_OBJ);

        return $response->toplamAlinanUcret;
    }

    public function moneyReceivedMonth(){
        $d = strtotime("+1 Months");
        $endDate = date("Y-m-d", $d);
        $moneyReceivedMonthDatabase = $this->baglanti->prepare("SELECT SUM(odenecek_ucret - odenen_ucret) as buAyOdenecekUcret  FROM taksitler WHERE taksitler.odenecek_tarih <= :endTime AND taksitler.odenecek_tarih >= :nowDate AND taksit_durum_id != 2");
        $moneyReceivedMonthDatabase->bindValue(":endTime",$endDate,PDO::PARAM_STR);
        $moneyReceivedMonthDatabase->bindValue(":nowDate",date("Y-m-d"),PDO::PARAM_STR);
        $moneyReceivedMonthDatabase->execute();
        $response = $moneyReceivedMonthDatabase->fetch(PDO::FETCH_OBJ);

        return $response->buAyOdenecekUcret;
    }

    public function willPayThisMonth(){
        $d = strtotime("+1 Months");
        $endDate = date("Y-m-d", $d);
        $willPayMonth = $this->baglanti->prepare("SELECT `kullanicilar`.`ad` AS `ad`, `kullanicilar`.`soyad` AS `soyad`, 
                                                        `kullanicilar`.`telefon` AS `telefon`, `satislar`.`taksit_sayi` AS `taksit_sayi`, 
                                                        `taksitler`.`taksit_durum_id` AS `taksit_durum_id`, `taksitler`.`odenecek_tarih` AS `odenecek_tarih`,
                                                        `taksitler`.`odenecek_ucret` AS `odenecek_ucret`, `hizmetler`.`hizmet_adi` AS `hizmet_adi` 
                                                        FROM (((`taksitler` join `satislar` on(`satislar`.`satis_id` = `taksitler`.`satis_id`)) 
                                                            join `hizmetler` on(`hizmetler`.`hizmet_id` = `satislar`.`hizmet_id`)) 
                                                            join `kullanicilar` on(`kullanicilar`.`musteri_id` = `satislar`.`musteri_id`)) 
        WHERE taksitler.odenecek_tarih <= :endTime AND taksitler.odenecek_tarih >= :nowDate AND taksitler.taksit_durum_id != 2");
        $willPayMonth->bindValue(":endTime",$endDate,PDO::PARAM_STR);
        $willPayMonth->bindValue("nowDate",date("Y-m-d"),PDO::PARAM_STR);
        $willPayMonth->execute();
        $willPayMonthResponse = $willPayMonth->fetchAll(PDO::FETCH_ASSOC);

        if($willPayMonthResponse){
            $response["willPayThisMonth"] = array();

            foreach($willPayMonthResponse as $willPayMonth){
                $willPayThisMonth = $this->addWillPayThisMonth($willPayMonth);
                array_push($response["willPayThisMonth"],$willPayThisMonth);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Bu aya ait ödeme yapıcak kişiler başarıyla getirildi";
        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Bu Ödeme yapıcak müşteri bilgisi bulunamadı";
        }
        return $response;
    }



    private function addWhoPayDayModel($whoPayDay){
        $whoPayDayModel = new PaymentModel();

        $whoPayDayModel->setReceivedFee($whoPayDay["alinan_ucret"]);
        $whoPayDayModel->setEmployeeName($whoPayDay["calisan_adi"]);
        $whoPayDayModel->setEmployeeSurname($whoPayDay["calisan_soyad"]);
        $whoPayDayModel->setTotalFee($whoPayDay["toplam_ucret"]);
        $whoPayDayModel->setPaymentTypeId($whoPayDay["odeme_tur_id"]);
        $whoPayDayModel->setServiceName($whoPayDay["hizmet_adi"]);
        $whoPayDayModel->setCostumerName($whoPayDay["musteri_ad"]);
        $whoPayDayModel->setCostumerSurname($whoPayDay["musteri_soyad"]);
        $whoPayDayModel->setPaymentType($whoPayDay["odeme_tur"]);

        return $whoPayDayModel->toString();
    }

    public function addWillPayThisMonth($queryWillPayThisMonth){
        $willPayThisMonth = new WillPayThisMonthModel();

        $willPayThisMonth->setCostumerName($queryWillPayThisMonth["ad"]);
        $willPayThisMonth->setCostumerSurname($queryWillPayThisMonth["soyad"]);
        $willPayThisMonth->setCostumerPhone($queryWillPayThisMonth["telefon"]);
        $willPayThisMonth->setInstallmentStatus($queryWillPayThisMonth["taksit_durum_id"]);
        $willPayThisMonth->setPaymentTime($queryWillPayThisMonth["odenecek_tarih"]);
        $willPayThisMonth->setFeePayable($queryWillPayThisMonth["odenecek_ucret"]);
        $willPayThisMonth->setServiceName($queryWillPayThisMonth["hizmet_adi"]);

        return $willPayThisMonth->toString();
    }



    private function addPaymentModel($payment){
        $paymentModel = New PaymentModel();

        $paymentModel->setPaymentId($payment["odeme_id"]);
        $paymentModel->setPaymentDate($payment["odeme_tarih"]);
        $paymentModel->setReceivedFee($payment["alinan_ucret"]);
        $paymentModel->setPaymentTypeId($payment["odeme_tur_id"]);
        $paymentModel->setPaymentType($payment["odeme_tur"]);
        $paymentModel->setEmployeeId($payment["calisan_id"]);
        $paymentModel->setEmployeeName($payment["calisan_adi"]);
        $paymentModel->setEmployeeSurname($payment["calisan_soyadi"]);
        $paymentModel->setServiceId($payment["hizmet_id"]);
        $paymentModel->setServiceName($payment["hizmet_adi"]);
        $paymentModel->setServiceTime($payment["tahmini_hizmet_suresi"]);
        $paymentModel->setServicePreviewUrl($payment["hizmet_onizleme_url"]);
        return $paymentModel->toString();
    }

    private function reducingTheSalesFee($sales_id, $canceledPaymentFee){
        $salesService = new SalesServiceImp();
        $salesService->cancelPaymentReduceFee($sales_id, $canceledPaymentFee);
    }

    public function __destruct(){
        parent::__destruct();
    }

}

?>
