<?php
require_once(__DIR__ . '/SalesService.php');
require_once(__DIR__ . '/SalesModel.php');
require_once(__DIR__ . '/../installments/InstallmentServiceImp.php');
require_once(__DIR__ . '/../payment/PaymentServiceImp.php');
require_once(__DIR__ . '/../Veritabani.php');

class SalesServiceImp extends Veritabani implements SalesService{


    public function __construct(){
        parent::__construct();
    }

    public function fetchAllSales(){
        $response = array();

        $queryFetchAllSales = $this->baglanti->query("SELECT 
                                                satis.satis_id, satis.toplam_ucret,
                                                satis.odenen_ucret, satis.satis_detay,
                                                satis.taksit_sayi,
                                                hizmet.hizmet_id, hizmet.hizmet_adi,
                                                hizmet.tahmini_hizmet_suresi, hizmet.hizmet_onizleme_url,
                                                durum.satis_durum_id, durum.satis_durum, 
                                                calisan.ad as calisan_adi, calisan.soyad as calisan_soyadi,
                                                calisan.yetki_id, satis.satisi_yapan_id, 
                                                musteri.telefon as musteri_telefon, musteri.musteri_id,
                                                musteri.ad as musteri_ad, musteri.soyad as musteri_soyad,
                                                musteri.kullanici_tc as musteri_tc, musteri.dogum_tarih as musteri_dogum_tarih,
                                                musteri.adres as musteri_adres, musteri.meslek as musteri_meslek,
                                                musteri.cinsiyet_id, cinsiyet.cinsiyet
                                            FROM satislar as satis
                                            INNER JOIN hizmetler as hizmet ON hizmet.hizmet_id = satis.hizmet_id
                                            INNER JOIN satis_durum as durum ON durum.satis_durum_id = satis.satis_durum_id
                                            INNER JOIN calisanlar as calisan ON calisan.musteri_id = satis.satisi_yapan_id
                                            INNER JOIN musteriler as musteri ON musteri.musteri_id = satis.musteri_id
                                            INNER JOIN cinsiyet ON cinsiyet.cinsiyet_id = musteri.cinsiyet_id");
        
        $queryFetchAllSales->execute();
        $salesResponse = $queryFetchAllSales->fetchAll(PDO::FETCH_ASSOC);

        if($salesResponse){
            $response["sales"] = array();

            foreach($salesResponse as $sales){
                $salesModel = $this->addSalesModel($sales);
                array_push($response["sales"],$salesModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Satışlar başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Satis bilgileri bulunamadı";
        }

        return $response;
    }

    public function fetchAllSalesByCostumerId($costumer_id){
        $response = array();

        $queryFetchSalesById = $this->baglanti->prepare("SELECT 
                                                satis.satis_id, satis.toplam_ucret,
                                                satis.odenen_ucret, satis.satis_detay,
                                                satis.taksit_sayi, satis.kapora,
                                                hizmet.hizmet_id, hizmet.hizmet_adi,
                                                hizmet.tahmini_hizmet_suresi, hizmet.hizmet_onizleme_url,
                                                hizmet.hizmet_resim,
                                                durum.satis_durum_id, durum.satis_durum, 
                                                calisan.ad as calisan_adi, calisan.soyad as calisan_soyadi,
                                                calisan.yetki_id, satis.satisi_yapan_id, 
                                                musteri.telefon as musteri_telefon, musteri.musteri_id,
                                                musteri.ad as musteri_ad, musteri.soyad as musteri_soyad,
                                                musteri.kullanici_tc as musteri_tc, musteri.dogum_tarih as musteri_dogum_tarih,
                                                musteri.adres as musteri_adres, musteri.meslek as musteri_meslek,
                                                musteri.cinsiyet_id, cinsiyet.cinsiyet
                                            FROM satislar           as satis
                                            INNER JOIN hizmetler    as hizmet  ON hizmet.hizmet_id       = satis.hizmet_id
                                            INNER JOIN satis_durum  as durum   ON durum.satis_durum_id   = satis.satis_durum_id
                                            INNER JOIN kullanicilar as calisan ON calisan.musteri_id     = satis.satisi_yapan_id
                                            INNER JOIN kullanicilar as musteri ON musteri.musteri_id     = satis.musteri_id
                                            INNER JOIN cinsiyet                ON cinsiyet.cinsiyet_id   = musteri.cinsiyet_id
                                            WHERE satis.musteri_id = :musteri_id ORDER BY satis.satis_id DESC");
        $queryFetchSalesById->bindValue(":musteri_id", $costumer_id, PDO::PARAM_INT);
        $queryFetchSalesById->execute();
        $salesResponse = $queryFetchSalesById->fetchAll(PDO::FETCH_ASSOC);

        if($salesResponse){
            $response["sales"] = array();

            foreach($salesResponse as $sales){
                $salesModel = $this->addSalesModel($sales);
                array_push($response["sales"],$salesModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Satışlar başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Satis bilgileri bulunamadı";
        }

        return $response;
    }

    public function servicesReceivedByTheCustomer($costumerId){
        $response = array();

        $serviceReceived = $this->baglanti->prepare("SELECT 
                                                             satislar.satis_id,
                                                             hizmetler.hizmet_adi, hizmetler.hizmet_id
                                                           FROM satislar
                                                   INNER JOIN hizmetler ON hizmetler.hizmet_id = satislar.hizmet_id
                                                   WHERE musteri_id = :musteri_id AND satis_durum_id = 1");
        $serviceReceived->bindValue("musteri_id",$costumerId);
        $serviceReceived->execute();
        $responseServiceReceived = $serviceReceived->fetchAll(PDO::FETCH_ASSOC);

        if($responseServiceReceived){
            $response["services"] = array();

            foreach($responseServiceReceived as $service){
                $serviceModel = $this->addService($service);
                array_push($response["services"],$serviceModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Aktif hizmetler başarıyla getirildi";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Aktif hizmet bilgisi bulunamadı";
        }

        return $response;
    }

    private function addService($service){
        $saleModel = new SalesModel();

        $saleModel->setSalesId($service["satis_id"]);
        $saleModel->setServiceName($service["hizmet_adi"]);

        return $saleModel->toString();
    }

    public function addSales($salesModel, $payment_status_id){
        $response = array();

        $service_id          = $salesModel->getServiceId();
        $total_fee           = $salesModel->getTotalFee();
        $the_fee_paid        = $salesModel->getFeePaid();
        $employeeId          = $salesModel->getEmployeeId();
        $installment_numbers = $salesModel->getInstallmentNumber();
        $sales_details       = $salesModel->getSalesDetails();
        $sales_status_id     = 1;
        $costumer_id         = $salesModel->getCostumerId();

        $addSales = $this->baglanti->prepare("INSERT INTO 
                                                satislar(hizmet_id, satisi_yapan_id, 
                                                         toplam_ucret, musteri_id,
                                                         odenen_ucret, taksit_sayi,
                                                         satis_detay, satis_durum_id,kapora)
                                                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
        $addSales->bindParam(1, $service_id         , PDO::PARAM_INT);
        $addSales->bindParam(2, $employeeId         , PDO::PARAM_INT);
        $addSales->bindParam(3, $total_fee          , PDO::PARAM_STR);
        $addSales->bindParam(4, $costumer_id        , PDO::PARAM_INT);
        $addSales->bindParam(5, $the_fee_paid       , PDO::PARAM_STR);
        $addSales->bindParam(6, $installment_numbers, PDO::PARAM_INT);
        $addSales->bindParam(7, $sales_details      , PDO::PARAM_STR);
        $addSales->bindParam(8, $sales_status_id    , PDO::PARAM_INT);
        $addSales->bindParam(9, $the_fee_paid       , PDO::PARAM_STR);
        $salesResponse = $addSales->execute();


        if($salesResponse){
            $sales_id = $this->baglanti->lastInsertId();

            $this->installments($sales_id, $total_fee, $the_fee_paid, $installment_numbers);
            $this->paymentControl($sales_id, $the_fee_paid, $employeeId, $payment_status_id);

            $response["success"] = parent::BASARILI;
            $response["message"] = "Satış başarıyla eklendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["success"] = "Satış eklenemedi";
        }
        
        return $response;
    }

    public function updateSalesStatus($sales_id, $sales_status_id){
        $response = array();

        $updateSalesStatus = $this->baglanti->prepare("UPDATE satislar SET satis_durum_id = :satis_durum_id 
                                                        WHERE satis_id = :satis_id");
        $updateSalesStatus->bindValue(":satis_durum_id", $sales_status_id, PDO::PARAM_INT);
        $updateSalesStatus->bindValue(":satis_id"      , $sales_id      , PDO::PARAM_INT);
        $updateSalesStatus->execute();

        if($updateSalesStatus->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Satis durum başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Satis durum güncellenemedi";
        }

        return $response;
    }

    public function cancelPaymentReduceFee($sales_id, $feeToBeReduced){
        $queryTheFeePaid = $this->baglanti->prepare("SELECT odenen_ucret FROM satislar WHERE satis_id = :satis_id");
        $queryTheFeePaid->bindValue(":satis_id", $sales_id, PDO::PARAM_INT);
        $queryTheFeePaid->execute();
        $theFeePaidResponse = $queryTheFeePaid->fetchAll(PDO::FETCH_ASSOC);
        
        $theFeePaid = $theFeePaidResponse[0]["odenen_ucret"];
        $saleContinuesId = 1;
        
        
        $newPaidFee = $theFeePaid - $feeToBeReduced;
        
        $this->databaseFeeReceivedUpdate($newPaidFee, $sales_id, $saleContinuesId);
    }

    public function deleteSale($saleId){
        $response = array();

        $installment = $this->baglanti->query("SELECT COUNT(*) as insallmentNumber FROM taksitler WHERE satis_id = $saleId")->fetch(PDO::FETCH_OBJ);
        $installmentId = $this->baglanti->query("SELECT taksit_id FROM taksitler WHERE satis_id = $saleId")->fetchAll(PDO::FETCH_OBJ);
        if($installment->insallmentNumber > 0){

            foreach($installmentId as $id){
                $deleteInformaiton = $this->baglanti->prepare("DELETE FROM bilgilendirme WHERE taksit_id = :taksit_id");
                $deleteInformaiton->bindValue("taksit_id",$id->taksit_id);
                $deleteInformaiton->execute();
            }

            $this->baglanti->exec("DELETE FROM odemeler WHERE satis_id = $saleId");
            $deleteInsallment = $this->baglanti->prepare("DELETE FROM taksitler WHERE satis_id = :satis_id");
            $deleteInsallment->bindValue("satis_id",$saleId);
            $deleteInsallment->execute();


            if($deleteInsallment->rowCount() > 0){
                $response = $this->deleteSaleDatabase($saleId);
            }else{
                $response["success"] = parent::BASARISIZ;
                $response["message"] = "Satışı silerken hata oluştu";
            }
        }else{
            $response = $this->deleteSaleDatabase($saleId);
        }


        return $response;
    }

    public function saleCheck(){

        $allSale = $this->baglanti->query("SELECT * FROM satislar WHERE satis_durum_id = 1")->fetchAll(PDO::FETCH_OBJ);

        foreach($allSale as $sale){
            $toplamUcret = $sale->toplam_ucret;
            $odenenUcret = $sale->odenen_ucret;
            $satisId     = $sale->satis_id;
            if($odenenUcret >= $toplamUcret){
                $updateSale = $this->baglanti->exec("UPDATE satislar SET satis_durum_id = 3 WHERE satis_id = $satisId");
            }
        }
    }

    public function deleteSaleDatabase($saleId){
        $deleteSale= $this->baglanti->prepare("DELETE FROM satislar WHERE satis_id = :satis_id");
        $deleteSale->bindValue("satis_id",$saleId);
        $deleteSale->execute();

        if($deleteSale->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Satış başarıyla iptal edildi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Satışı silerken hata oluştu";
        }

        return $response;
    }

    public function updateSaleDetails($saleDetails, $saleId){
        $response = array();

        $saleDetailsUpdate = $this->baglanti->prepare("UPDATE satislar SET satis_detay = :satis_detay WHERE satis_id = :satis_id");
        $saleDetailsUpdate->bindValue("satis_detay",$saleDetails,PDO::PARAM_STR);
        $saleDetailsUpdate->bindValue("satis_id"   , $saleId);
        $saleDetailsUpdate->execute();

        if($saleDetailsUpdate->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Satış detayı başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Satış detay güncelleme hatası";
        }

        return $response;
    }


    private function installments($sales_id, $total_fee, $the_fee_paid, $installment_numbers){
        if(($total_fee != $the_fee_paid) && ($installment_numbers > 1)){
            $installmentTotalFee = $total_fee - $the_fee_paid;

            $installmentService = new InstallmentServiceImp();
            $installmentService->addInstallment($sales_id , $installmentTotalFee, $installment_numbers);
        }
    }

    private function paymentControl($sales_id, $the_fee_paid,  $employeeId, $payment_status_id){
        if($the_fee_paid > 0){
            $paymentService = new PaymentServiceImp();
            $paymentModel   = new PaymentModel();

            $date = date("Y-m-d");

            $paymentModel->setSalesId($sales_id);
            $paymentModel->setPaymentDate($date);
            $paymentModel->setReceivedFee($the_fee_paid);
            $paymentModel->setEmployeeId($employeeId);
            $paymentModel->setPaymentTypeId($payment_status_id);

            $paymentService->addPayment($paymentModel);
        }
    }

    public function updateReceivedFee($sales_id, $paymet_made){

        $queryReceivedFee = $this->baglanti->prepare("SELECT 
                                                        satis.odenen_ucret, satis.toplam_ucret
                                                      FROM satislar as satis 
                                                      WHERE satis.satis_id = :satis_id");
        $queryReceivedFee->bindValue(":satis_id", $sales_id, PDO::PARAM_INT);
        $queryReceivedFee->execute();
        $receivedFeeResponse = $queryReceivedFee->fetchAll(PDO::FETCH_ASSOC);

        $receivedFee = $receivedFeeResponse[0]["odenen_ucret"];
        $totalFee    = $receivedFeeResponse[0]["toplam_ucret"];

        $keepsUpToDate = $receivedFee + $paymet_made;

        if($receivedFee >= $totalFee){
            $saleTerminatedId = 3;

            $this->databaseFeeReceivedUpdate($keepsUpToDate, $sales_id, $saleTerminatedId);
        }else{
            $saleContinuesId = 1;

            $this->databaseFeeReceivedUpdate($keepsUpToDate, $sales_id, $saleContinuesId);
        }

    }

    private function databaseFeeReceivedUpdate($newPaidFee, $sales_id, $sales_status_id){
        $updateSalesReceivedFee = $this->baglanti->prepare("UPDATE satislar SET odenen_ucret = :odenen_ucret, satis_durum_id = :satis_durum_id WHERE satis_id = :satis_id");
        $updateSalesReceivedFee->bindValue(":odenen_ucret"  , $newPaidFee     , PDO::PARAM_STR);
        $updateSalesReceivedFee->bindValue(":satis_id"      , $sales_id       , PDO::PARAM_INT);
        $updateSalesReceivedFee->bindValue(":satis_durum_id", $sales_status_id, PDO::PARAM_INT);
        $updateSalesReceivedFee->execute();
    }

    public function addSalesModel($sales){
        $salesModel = new SalesModel();

        $salesModel->setSalesId($sales["satis_id"]);
        $salesModel->setTotalFee($sales["toplam_ucret"]);
        $salesModel->setFeePaid($sales["odenen_ucret"]);
        $salesModel->setKapora($sales["kapora"]);
        $salesModel->setEmployeeId($sales["satisi_yapan_id"]);
        $salesModel->setInstallmentNumber($sales["taksit_sayi"]);
        $salesModel->setEmployeeName($sales["calisan_adi"]);
        $salesModel->setEmployeeSurname($sales["calisan_soyadi"]);
        $salesModel->setCostumerPhone($sales["musteri_telefon"]);
        $salesModel->setCostumerId($sales["musteri_id"]);
        $salesModel->setCostumerTc($sales["musteri_tc"]);
        $salesModel->setCostumerName($sales["musteri_ad"]);
        $salesModel->setCostumerSurname($sales["musteri_soyad"]);
        $salesModel->setCostumerBirthday($sales["musteri_dogum_tarih"]);
        $salesModel->setCostumerAddress($sales["musteri_adres"]);
        $salesModel->setCostumerProfession($sales["musteri_meslek"]);
        $salesModel->setCostumerGenderId($sales["cinsiyet_id"]);
        $salesModel->setSalesDetails($sales["satis_detay"]);
        $salesModel->setSalesStatusId($sales["satis_durum_id"]);
        $salesModel->setServiceId($sales["hizmet_id"]);
        $salesModel->setServiceName($sales["hizmet_adi"]);
        $salesModel->setServiceImage($sales["hizmet_resim"]);
        $salesModel->setServicePreviewUrl($sales["hizmet_onizleme_url"]);
        $salesModel->setServiceTime($sales["tahmini_hizmet_suresi"]);

        return $salesModel->toString();
    }

    public function __destruct(){
        parent::__destruct();
    }


}



?>
