<?php
require_once(__DIR__ . '/ServiceInterface.php');
require_once(__DIR__ . '/ServiceModel.php');
require_once(__DIR__ . '/../Veritabani.php');

class ServiceInterfaceImp extends Veritabani implements ServiceInterface{


    public function __construct(){
        parent::__construct();
    }

    public function webFetchAllServices(){
        $response = array();

        $QueryServicesFetch = $this->baglanti->query("SELECT * FROM hizmetler WHERE durum = 1");
        $QueryServicesFetch->execute();

        $servicesResponse = $QueryServicesFetch->fetchAll(PDO::FETCH_ASSOC);

        if($servicesResponse){
            $response["services"] = array();

            foreach($servicesResponse as $service){
                $serviceModel = $this->addServiceModel($service);
                array_push($response["services"], $serviceModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Hizmetler başarıyla alındı";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Hizmet bilgisi bulunamadı";
        }
        
        return $response;
    }

    public function webFetchAllServicesForServices(){
        $response = array();

        $QueryServicesFetch = $this->baglanti->query("SELECT * FROM hizmetler");
        $QueryServicesFetch->execute();

        $servicesResponse = $QueryServicesFetch->fetchAll(PDO::FETCH_ASSOC);

        if($servicesResponse){
            $response["services"] = array();

            foreach($servicesResponse as $service){
                $serviceModel = $this->addServiceModel($service);
                array_push($response["services"], $serviceModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Hizmetler başarıyla alındı";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Hizmet bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchAllServices(){
        $response = array();

        $QueryServicesFetch = $this->baglanti->query("SELECT * FROM hizmetler WHERE durum = 1");
        $QueryServicesFetch->execute();

        $servicesResponse = $QueryServicesFetch->fetchAll(PDO::FETCH_ASSOC);

        if($servicesResponse){
            $response["services"] = array();

            foreach($servicesResponse as $service){
                $serviceModel = $this->addServiceModel($service);
                array_push($response["services"], $serviceModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Hizmetler başarıyla alındı";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Hizmet bilgisi bulunamadı";
        }
        
        return $response;
    }

    public function fetchServiceInformation($service_id){
        $response = array();

        $fetchServiceInformation = $this->baglanti->prepare("SELECT * FROM hizmetler WHERE hizmet_id = :hizmet_id");
        $fetchServiceInformation->bindValue(":hizmet_id", $service_id, PDO::PARAM_INT);
        $fetchServiceInformation->execute();

        $servicesResponse = $fetchServiceInformation->fetchAll(PDO::FETCH_ASSOC);

        if($servicesResponse){
            $response["service"] = $this->addServiceModel($servicesResponse[0]);
            $response["success"] = parent::BASARILI;
            $response["message"] = "Hizmet bilgileri başarıyla alındı";

        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Hizmet bilgisi bulunamadı";
        }
        
        return $response;
    }

    public function addService($service_name, $service_time, $service_image, $service_preview_url){
        $response = array();

        if($this->isThereService($service_name)){

            if(empty($service_preview_url)){
                $queryAddService = $this->baglanti->prepare("INSERT INTO hizmetler(hizmet_adi, tahmini_hizmet_suresi, hizmet_resim) VALUES (?,?,?)");
                $queryAddService->bindParam(1, $service_name       , PDO::PARAM_STR);
                $queryAddService->bindParam(2, $service_time       , PDO::PARAM_STR);
                $queryAddService->bindParam(3, $service_image      , PDO::PARAM_STR);
            }else{
                $queryAddService = $this->baglanti->prepare("INSERT INTO hizmetler(hizmet_adi, tahmini_hizmet_suresi, hizmet_resim, hizmet_onizleme_url) VALUES (?,?,?,?)");
                $queryAddService->bindParam(1, $service_name       , PDO::PARAM_STR);
                $queryAddService->bindParam(2, $service_time       , PDO::PARAM_STR);
                $queryAddService->bindParam(3, $service_image      , PDO::PARAM_STR);
                $queryAddService->bindParam(4, $service_preview_url, PDO::PARAM_STR);
            }
            $serviceAddResult = $queryAddService->execute();

            if($serviceAddResult){
                $response["success"] = parent::BASARILI;
                $response["message"] = "Hizmet başarıyla eklendi";
            }else{
                $response["success"] = parent::BASARISIZ;
                $response["message"] = "Hizmet eklenemedi";
            }
        }else{
            $response["success"] = parent::MEVCUT;
            $response["message"] = "Hizmet sistemde mevcut";
        }

        return $response;
    }

    public function passiveService($service_id){
        $response = array();

        $queryDeleteService = $this->baglanti->prepare("UPDATE hizmetler SET durum = :durum WHERE hizmet_id = :hizmet_id");
        $queryDeleteService->bindValue(":durum"    , 0          , PDO::PARAM_INT);
        $queryDeleteService->bindValue(":hizmet_id", $service_id, PDO::PARAM_INT);
        $queryDeleteService->execute();

        if($queryDeleteService->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Hizmet başarıyla pasif hale getirildi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Hizmet pasif hale getirilirken hata oluştu";
        }
        
        return $response;
    }

    public function activeService($service_id){
        $response = array();

        $queryDeleteService = $this->baglanti->prepare("UPDATE hizmetler SET durum = :durum WHERE hizmet_id = :hizmet_id");
        $queryDeleteService->bindValue(":durum"    , 1          , PDO::PARAM_INT);
        $queryDeleteService->bindValue(":hizmet_id", $service_id, PDO::PARAM_INT);
        $queryDeleteService->execute();

        if($queryDeleteService->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Hizmet başarıyla aktif hale getirildi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Hizmet aktif hale getirilirken hata oluştu";
        }
        
        return $response;
    }

    public function editService($service_id, $service_name, $service_time, $service_preview_url, $service_image){
        $response = array();

        $queryEditService = $this->baglanti->prepare("UPDATE hizmetler SET hizmet_adi = :hizmet_adi, tahmini_hizmet_suresi = :hizmet_suresi,
                                                                           hizmet_onizleme_url = :hizmet_onizleme_url, hizmet_resim = :hizmet_resim  WHERE hizmet_id = :hizmet_id");
        $queryEditService->bindValue(":hizmet_adi"          , $service_name        , PDO::PARAM_STR);
        $queryEditService->bindValue(":hizmet_suresi"       , $service_time        , PDO::PARAM_STR);
        $queryEditService->bindValue(":hizmet_onizleme_url" , $service_preview_url , PDO::PARAM_STR);
        $queryEditService->bindValue(":hizmet_resim"        , $service_image       , PDO::PARAM_STR);
        $queryEditService->bindValue(":hizmet_id"           , $service_id          , PDO::PARAM_INT);
        $queryEditService->execute();

        if($queryEditService->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Hizmet başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Hizmet güncellenemedi";
        }
        
        return $response;
    }

    public function editService2($service_id, $service_name, $service_time, $service_preview_url){
        $response = array();

        $queryEditService = $this->baglanti->prepare("UPDATE hizmetler SET hizmet_adi = :hizmet_adi, tahmini_hizmet_suresi = :hizmet_suresi,
                                                                           hizmet_onizleme_url = :hizmet_onizleme_url  WHERE hizmet_id = :hizmet_id");
        $queryEditService->bindValue(":hizmet_adi"          , $service_name        , PDO::PARAM_STR);
        $queryEditService->bindValue(":hizmet_suresi"       , $service_time        , PDO::PARAM_STR);
        $queryEditService->bindValue(":hizmet_onizleme_url" , $service_preview_url , PDO::PARAM_STR);
        $queryEditService->bindValue(":hizmet_id"           , $service_id          , PDO::PARAM_INT);
        $queryEditService->execute();

        if($queryEditService->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Hizmet başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Hizmet güncellenemedi";
        }
        
        return $response;
    }

    private function isThereService($service_name){
        $queryThereIsService = $this->baglanti->prepare("SELECT hizmet_adi FROM hizmetler WHERE hizmet_adi = :hizmet_adi");
        $queryThereIsService->bindValue(":hizmet_adi", $service_name, PDO::PARAM_STR);
        $queryThereIsService->execute();
        $isThereServiceResponse = $queryThereIsService->fetchAll(PDO::FETCH_ASSOC);
        return !$isThereServiceResponse;
    }

    private function addServiceModel($service){
        $serviceModel = new ServiceModel();

        $serviceModel->setServiceId($service["hizmet_id"]);
        $serviceModel->setServiceName($service["hizmet_adi"]);
        $serviceModel->setServiceTime($service["tahmini_hizmet_suresi"]);
        $serviceModel->setServicePreviewUrl($service["hizmet_onizleme_url"]);
        $serviceModel->setServiceImage($service["hizmet_resim"]);
        $serviceModel->setStatus($service["durum"]);
        
        return $serviceModel->toString();
    }


    public function __destruct(){
        parent::__destruct();
    }

}


?>