<?php

require_once(__DIR__ . '/../../Veritabani.php');
require_once(__DIR__ . '/../UserModel.php');
require_once(__DIR__ . '/CostumerService.php');

class CostumerServiceImp extends Veritabani implements CostumerService{

    const NO_TC_INFORMATION = "11111111111";

    public function __construct(){
        parent::__construct();
    }

    public function fetchCostumerInformation($costumerId){
        $response = array();

        $costumerInformation = $this->baglanti->prepare("SELECT * FROM kullanicilar WHERE musteri_id = :costumer_id");
        $costumerInformation->bindValue(":costumer_id",$costumerId);
        $costumerInformation->execute();
        $responseCostumer = $costumerInformation->fetch(PDO::FETCH_OBJ);

        if($responseCostumer){
            $response["costumer"] = $responseCostumer;
            $response["success"]  = parent::BASARILI;
            $response["message"]  = "Müşteri bilgileri başarıyla getirildi";
        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Müşteri bilgisi bulunamadı";
        }

        return $response;
    }

    public function upComingBirthday(){
        $response = array();

        $costumerInformation = $this->baglanti->prepare("SELECT * FROM kullanicilar where DATE_ADD(dogum_Tarih, INTERVAL YEAR(CURDATE())-YEAR(dogum_Tarih) + IF(DAYOFYEAR(CURDATE()) > DAYOFYEAR(dogum_Tarih),1,0) YEAR) BETWEEN CURDATE() AND DATE_ADD(CURDATE(), INTERVAL 7 DAY)");
        $costumerInformation->execute();
        $responseCostumer = $costumerInformation->fetchAll(PDO::FETCH_OBJ);

        if($responseCostumer){
            $response["costumer"] = $responseCostumer;
            $response["success"]  = parent::BASARILI;
            $response["message"]  = "Müşteri bilgileri başarıyla getirildi";
        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Müşteri bilgisi bulunamadı";
        }

        return $response;
    }

    public function getInstallmentInformation($installment_id){
        $response = array();

        $installmentInformation = $this->baglanti->prepare("SELECT * FROM taksitler WHERE taksit_id = :taksit_id");
        $installmentInformation->bindValue("taksit_id",$installment_id);
        $installmentInformation->execute();
        $responseInstallment = $installmentInformation->fetch(PDO::FETCH_OBJ);

        if($responseInstallment){
            $response["installment"] = $responseInstallment;
            $response["success"]     = parent::BASARILI;
            $response["message"]     = "Taksit bilgisi başarıyla alındı";
        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Taksit bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchAllCostumer(){
        $response = array();

        $fetchAllCostumer = $this->baglanti->prepare("SELECT * FROM kullanicilar WHERE yetki_id = :yetki_id AND durum = :durum");
        $fetchAllCostumer->bindValue(":yetki_id", parent::COSTUMER_AUTHORITY, PDO::PARAM_INT);
        $fetchAllCostumer->bindValue(":durum"   , parent::ACTIVE            , PDO::PARAM_INT);
        $fetchAllCostumer->execute();
        $costumerResponse = $fetchAllCostumer->fetchAll(PDO::FETCH_ASSOC);

        if($costumerResponse){
            $response["users"] = array();

            foreach($costumerResponse as $costumer){
                $costumerModel = $this->addCostumerModel($costumer);
                array_push($response["users"],$costumerModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"] = "Müşteriler başarıyla çekildi";
        }else{
            $response["success"] = parent::BOS;
            $response["message"] = "Müşteri bilgisi bulunamadı";
        }

        return $response;
    }

    public function fetchCostumerInformationById($user_id){
        $response = array();

        $fetchCostumerInformation = $this->baglanti->prepare("SELECT * FROM kullanicilar WHERE musteri_id = :musteri_id");
        $fetchCostumerInformation->bindValue(":musteri_id", $user_id, PDO::PARAM_INT);
        $fetchCostumerInformation->execute();
        $responseCostumerInformation = $fetchCostumerInformation->fetchAll(PDO::FETCH_ASSOC);
        
        if($responseCostumerInformation){
            session_id(1);
            session_start();

            if(!isset($_SESSION['token'])){
                $_SESSION['token'] = bin2hex(random_bytes(64));
            }

            $response = $this->addCostumerModel($responseCostumerInformation[0]);
            $response["access_token"] = $_SESSION['token'];

            $response["success"]  = parent::BASARILI;
            $response["message"]  = "Başarıyla müşteri bilgileri getirildi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Müşteri bilgileri alınırken hata ile karşılaşıldı";
        }

        return $response;
    }

    public function fetchUpdateCostumerInformation($user_id){
        $response = array();

        $fetchCostumerInformation = $this->baglanti->prepare("SELECT * FROM kullanicilar WHERE musteri_id = :musteri_id");
        $fetchCostumerInformation->bindValue(":musteri_id", $user_id, PDO::PARAM_INT);
        $fetchCostumerInformation->execute();
        $responseCostumerInformation = $fetchCostumerInformation->fetchAll(PDO::FETCH_ASSOC);
        
        if($responseCostumerInformation){
            $response = $this->addCostumerModel($responseCostumerInformation[0]);
            $response["success"]  = parent::BASARILI;
            $response["message"]  = "Başarıyla müşteri bilgileri getirildi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Müşteri bilgileri alınırken hata ile karşılaşıldı";
        }

        return $response;
    }

    public function costumerAccessControl($user_name, $user_password){
        $response = array();

        $costumerAccessControl = $this->baglanti->prepare("SELECT * FROM kullanicilar WHERE kullanici_adi = :kullanici_adi 
                                                                                      AND kullanici_sifre = :kullanici_sifre");
        $costumerAccessControl->bindValue(":kullanici_adi"  , $user_name    , PDO::PARAM_STR);
        $costumerAccessControl->bindValue(":kullanici_sifre", $user_password, PDO::PARAM_STR);
        $costumerAccessControl->execute();
        $costumerResponse = $costumerAccessControl->fetchAll(PDO::FETCH_ASSOC);
        
        if($costumerResponse){
            session_id(1);
            session_start();

            if(!isset($_SESSION['token'])){
                $_SESSION['token'] = bin2hex(random_bytes(64));
            }

            $response = $this->addCostumerModel($costumerResponse[0]);
            $response["access_token"] = $_SESSION['token'];

            $response["success"]  = parent::BASARILI;
            $response["message"]  = "Başarıyla giriş yapıldı";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Giriş bilgileri hatalı";
        }

        return $response;
    }

    public function passiveUser($user_id){
        $response = array();

        $deleteUser = $this->baglanti->prepare("UPDATE kullanicilar SET durum = :durum WHERE musteri_id = :musteri_id");
        $deleteUser->bindValue(":durum"     , parent::PASSIVE,PDO::PARAM_INT);
        $deleteUser->bindValue(":musteri_id", $user_id       ,PDO::PARAM_INT);
        $deleteUser->execute();

        if($deleteUser->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Müşteri başarıyla pasif hale getirildi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Müşteri pasif hale getirelemedi sunucu hatası";
        }

        return $response;
    }


    public function webAddCostumer($userModel){
        $response = array();

        $userTc       = $userModel->getUserTc();
        $userName     = $userModel->getUserName();
        $userPassword = $userModel->getUserPassword(); 
        $name         = $userModel->getName();
        $surname      = $userModel->getSurname();
        $birthday     = date("Y-m-d",strtotime($userModel->getBirthday()));
        $address      = $userModel->getAddress();
        $profession   = $userModel->getProfession();
        $phoneNumber  = $userModel->getPhoneNumber();
        $genderId     = $userModel->getGenderId();

                $addCostumer = $this->baglanti->prepare("INSERT INTO kullanicilar(kullanici_tc, kullanici_adi, kullanici_sifre,
                                                            ad, soyad, dogum_tarih, adres, meslek, telefon, cinsiyet_id) 
                                                         VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
                $addCostumer->bindParam(1, $userTc                 , PDO::PARAM_STR);
                $addCostumer->bindParam(2, $userName               , PDO::PARAM_STR);
                $addCostumer->bindParam(3, $userPassword           , PDO::PARAM_STR);
                $addCostumer->bindParam(4, $name                   , PDO::PARAM_STR);
                $addCostumer->bindParam(5, $surname                , PDO::PARAM_STR);
                $addCostumer->bindParam(6, $birthday               , PDO::PARAM_STR);
                $addCostumer->bindParam(7, $address                , PDO::PARAM_STR);
                $addCostumer->bindParam(8, $profession             , PDO::PARAM_STR);
                $addCostumer->bindParam(9, $phoneNumber            , PDO::PARAM_STR);
                $addCostumer->bindParam(10,$genderId              , PDO::PARAM_INT);
                $addCostumerResponse = $addCostumer->execute();

                if($addCostumerResponse){
                    $response["success"] = parent::BASARILI;
                    $response["message"]  = "Müşteri başarıyla eklendi";
                }else{
                    $response["success"] = parent::BASARISIZ;
                    $response["message"]  = "Müşteri eklenirken hata ile karşılaşıldı tekrar deneyiniz";
                }

        return $response;
    }


    public function addCostumer($user_tc, $user_name, $user_password, $gender_id){
        $response = array();

        if($this->registerCheckTc($user_tc)){
            if($this->costumerUserNameCheck($user_name)){

                $addCostumer = $this->baglanti->prepare("INSERT INTO kullanicilar(kullanici_tc, kullanici_adi, kullanici_sifre, cinsiyet_id) 
                                                         VALUES (?, ?, ?, ?) ");
                $addCostumer->bindParam(1, $user_tc       , PDO::PARAM_STR);
                $addCostumer->bindParam(2, $user_name     , PDO::PARAM_STR);
                $addCostumer->bindParam(3, $user_password , PDO::PARAM_STR);
                $addCostumer->bindParam(4, $gender_id     , PDO::PARAM_INT);
                $addCostumerResponse = $addCostumer->execute();

                if($addCostumerResponse){
                    $response["success"] = parent::BASARILI;
                    $response["message"]  = "Müşteri başarıyla eklendi";
                }else{
                    $response["success"] = parent::BASARISIZ;
                    $response["message"]  = "Müşteri eklenirken hata ile karşılaşıldı tekrar deneyiniz";
                }
            }else{
                $response["success"] = parent::MEVCUT;
                $response["message"] = "Kullanıcı adı sistemde mevcut";
            }
        }else{
            $response["success"] = parent::MEVCUT;
            $response["message"]  = "Müşteri Tc si sistemde mevcut";
        }

        return $response;
    }

    public function updateCostumerInformation($userModel){
        $response = array();

        $userId      = $userModel->getUserId();
        $name        = $userModel->getName();
        $surname     = $userModel->getSurname();
        $birthday    = $userModel->getBirthday();
        $address     = $userModel->getAddress();
        $profession  = $userModel->getProfession();
        $phoneNumber = $userModel->getPhoneNumber();
           
          
        $queryCostumerInformationUpdate = $this->baglanti->prepare("UPDATE kullanicilar SET
                                                            ad          = :ad,
                                                            soyad       = :soyad,
                                                            dogum_tarih = :dogum_tarih,
                                                            adres       = :adres,
                                                            meslek      = :meslek,
                                                            telefon     = :telefon,
                                                            ilk_giris   = :ilk_giris
                                                            WHERE musteri_id    = :musteri_id");
        $queryCostumerInformationUpdate->bindValue(":ad"         , $name                  , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":soyad"      , $surname               , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":dogum_tarih", $birthday              , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":adres"      , $address               , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":meslek"     , $profession            , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":telefon"    , $phoneNumber           , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":ilk_giris"  , parent::NOT_FIRST_LOGIN, PDO::PARAM_INT);
        $queryCostumerInformationUpdate->bindValue(":musteri_id" , $userId                , PDO::PARAM_INT);
        $queryCostumerInformationUpdate->execute();
    
        if($queryCostumerInformationUpdate->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Müşteri bilgileri başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Müşteri bilgileri güncellenemedi";
        }

        return $response;
    }

    public function updateWebCostumerInformation($userModel){
        $response = array();

        $userId      = $userModel->getUserId();
        $userTc      = $userModel->getUserTc();
        $name        = $userModel->getName();
        $surname     = $userModel->getSurname();
        $birthday    = date('Y-m-d',strtotime($userModel->getBirthday()));
        $address     = $userModel->getAddress();
        $profession  = $userModel->getProfession();
        $genderId    = $userModel->getGenderId();
        $phoneNumber = $userModel->getPhoneNumber();
           
          
        $queryCostumerInformationUpdate = $this->baglanti->prepare("UPDATE kullanicilar SET
                                                            kullanici_tc = :kullanici_tc,
                                                            ad           = :ad,
                                                            soyad        = :soyad,
                                                            dogum_tarih  = :dogum_tarih,
                                                            adres        = :adres,
                                                            meslek       = :meslek,
                                                            cinsiyet_id  = :cinsiyet_id,
                                                            telefon      = :telefon
                                                            WHERE musteri_id    = :musteri_id");
        $queryCostumerInformationUpdate->bindValue(":kullanici_tc", $userTc                , PDO::PARAM_STR);                                                    
        $queryCostumerInformationUpdate->bindValue(":ad"          , $name                  , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":soyad"       , $surname               , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":dogum_tarih" , $birthday              , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":adres"       , $address               , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":meslek"      , $profession            , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":telefon"     , $phoneNumber           , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":cinsiyet_id" , $genderId              , PDO::PARAM_INT);
        $queryCostumerInformationUpdate->bindValue(":musteri_id"  , $userId                , PDO::PARAM_INT);
        $queryCostumerInformationUpdate->execute();
    
        if($queryCostumerInformationUpdate->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Müşteri bilgileri başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Müşteri bilgileri güncellenemedi";
        }

        return $response;
    }



    public function editCostumer($userModel){
        $response = array();

        $userId      = $userModel->getUserId();
        $userTc      = $userModel->getUserTc();
        $name        = $userModel->getName();
        $surname     = $userModel->getSurname();
        $birthday    = $userModel->getBirthday();
        $address     = $userModel->getAddress();
        $profession  = $userModel->getProfession();
        $phoneNumber = $userModel->getPhoneNumber();
        $genderId    = $userModel->getGenderId();
        
        if($this->costumerTcCheck($userTc,$userId)){
            
            $queryEditCostumer = $this->baglanti->prepare("UPDATE kullanicilar SET
                                    kullanici_tc = :kullanici_tc,
                                    ad           = :ad,
                                    soyad        = :soyad,
                                    dogum_tarih  = :dogum_tarih,
                                    adres        = :adres,
                                    meslek       = :meslek,
                                    cinsiyet_id  = :cinsiyet_id,
                                    telefon      = :telefon
                                    WHERE musteri_id = :musteri_id");
            $queryEditCostumer->bindValue(":kullanici_tc" , $userTc      , PDO::PARAM_INT);
            $queryEditCostumer->bindValue(":ad"           , $name        , PDO::PARAM_STR);
            $queryEditCostumer->bindValue(":soyad"        , $surname     , PDO::PARAM_STR);
            $queryEditCostumer->bindValue(":dogum_tarih"  , $birthday    , PDO::PARAM_STR);
            $queryEditCostumer->bindValue(":adres"        , $address     , PDO::PARAM_STR);
            $queryEditCostumer->bindValue(":meslek"       , $profession  , PDO::PARAM_STR);
            $queryEditCostumer->bindValue(":cinsiyet_id"  , $genderId    , PDO::PARAM_INT);
            $queryEditCostumer->bindValue(":telefon"      , $phoneNumber , PDO::PARAM_STR);
            $queryEditCostumer->bindValue(":musteri_id"   , $userId      , PDO::PARAM_STR);
            $queryEditCostumer->execute();

            if($queryEditCostumer->rowCount() > 0){
                $response["success"] = parent::BASARILI;
                $response["message"] = "Müşteri bilgileri başarıyla güncellendi";
            }else{
                $response["success"] = parent::BASARISIZ;
                $response["message"] = "Müşteri bilgileri güncellenemedi";
            }   
        }else{
            $response["success"] = parent::MEVCUT;
            $response["message"]  = "Müşteri Tc si sistemde mevcut";
        }
        
        return $response;
    }

    public function editCostumerProfilePhoto($user_id,$profile_photo){
        $response = array();

        $baseProfilePhoto = "Veritabani/" . $profile_photo;


        $queryEditCostumerPhoto = $this->baglanti->prepare("UPDATE kullanicilar SET profil_fotograf = :profil_fotograf WHERE musteri_id = :musteri_id");
        $queryEditCostumerPhoto->bindValue(":profil_fotograf", $baseProfilePhoto, PDO::PARAM_STR);
        $queryEditCostumerPhoto->bindValue(":musteri_id"     , $user_id         , PDO::PARAM_INT);
        $queryEditCostumerPhoto->execute();

        if($queryEditCostumerPhoto->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = $baseProfilePhoto;
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Üzgünüz, profil resminiz güncellenirken hata oluştu.";
        }

        return $response;
    }

    public function costumerUpdatePassword($userId, $currentPassword, $newPassword){
        $response = array();

        $queryCostumerInfo = $this->baglanti->prepare("SELECT kullanici_sifre FROM kullanicilar WHERE musteri_id = :musteri_id");
        $queryCostumerInfo->bindValue(":musteri_id", $userId, PDO::PARAM_INT);
        $queryCostumerInfo->execute();
        $costumerResponse = $queryCostumerInfo->fetchAll(PDO::FETCH_ASSOC);

        if($costumerResponse){
            $costumerCurrentPassword = $costumerResponse[0]["kullanici_sifre"];

            if($costumerCurrentPassword == $currentPassword){
                $response = $this->updatePasswordWithDatabase($userId, $newPassword);
            }else{
                $response["success"] = parent::BASARISIZ;
                $response["message"] = "Mevcut şifrenizi hatalı girdiniz";
            }

        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Üzgünüz, müşteri bilgilerinize ulaşamadık tekrar deneyiniz...";
        }

        return $response;
    }

    public function updatePasswordWithDatabase($userId, $newPassword){
        $response = array();


        $queryUpdateCostumerPassword = $this->baglanti->prepare("UPDATE kullanicilar SET kullanici_sifre = :kullanici_sifre WHERE musteri_id = :musteri_id");
        $queryUpdateCostumerPassword->bindValue(":kullanici_sifre", $newPassword, PDO::PARAM_STR);
        $queryUpdateCostumerPassword->bindValue(":musteri_id"     , $userId     , PDO::PARAM_INT);
        $queryUpdateCostumerPassword->execute();

        if($queryUpdateCostumerPassword->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Tebrikler, şifreniz güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Üzgünüz, şifrenizi güncelleyemedik tekrar deneyiniz...";
        }

        return $response;
    }

    private function costumerTcCheck($userTc, $userId){
            if($userTc != self::NO_TC_INFORMATION){
                $costumerAccessControl = $this->baglanti->prepare("SELECT musteri_tc FROM kullanicilar
                     WHERE musteri_id = :musteri_id");
                $costumerAccessControl->bindValue(":musteri_id", $userId, PDO::PARAM_STR);
                $costumerAccessControl->execute();
                $costumerResponse = $costumerAccessControl->fetchAll(PDO::FETCH_ASSOC);
            
            if($costumerResponse){
                
                $responseCostumerTc = $costumerResponse[0]["kullanici_tc"];
                
                if($responseCostumerTc == $costumer_tc){
                    return true;
                }else{
                    $checkCostumer = $this->baglanti->prepare("SELECT kullanici_tc FROM kullanicilar WHERE kullanici_tc = :kullanici_tc");
    
                    $checkCostumer->bindValue(":kullanici_tc" , $userTc, PDO::PARAM_STR);
    
                    $checkCostumer->execute();
                    $checkCostumerResponse = $checkCostumer->fetchAll(PDO::FETCH_ASSOC);
                    return !$checkCostumerResponse;
                }
                
            }else{
                return true;
            }
          }
        return true;
    }

    private function registerCheckTc($userTc){
        if($userTc != self::NO_TC_INFORMATION){
            $checkCostumer = $this->baglanti->prepare("SELECT kullanici_tc FROM kullanicilar WHERE kullanici_tc = :kullanici_tc");
    
            $checkCostumer->bindValue(":kullanici_tc", $userTc, PDO::PARAM_STR);
    
            $checkCostumer->execute();
            $checkCostumerResponse = $checkCostumer->fetchAll(PDO::FETCH_ASSOC);
            return !$checkCostumerResponse;
        }
        return true;
    }
    
    private function costumerUserNameCheck($user_name){
        $checkCostumer = $this->baglanti->prepare("SELECT kullanici_adi FROM kullanicilar WHERE kullanici_adi = :kullanici_adi");
        $checkCostumer->bindValue(":kullanici_adi", $user_name , PDO::PARAM_STR);
        $checkCostumer->execute();
        $checkCostumerResponse = $checkCostumer->fetchAll(PDO::FETCH_ASSOC);
        return !$checkCostumerResponse;
    }

    public function addCostumerModel($costumer){
        $userModel = new UserModel();

        $userModel->setUserId($costumer["musteri_id"]);
        $userModel->setUserTc($costumer["kullanici_tc"]);
        $userModel->setUserName($costumer["kullanici_adi"]);
        $userModel->setProfilePhoto($costumer["profil_fotograf"]);
        $userModel->setName($costumer["ad"]);
        $userModel->setSurname($costumer["soyad"]);
        $userModel->setBirthday($costumer["dogum_tarih"]);
        $userModel->setAddress($costumer["adres"]);
        $userModel->setProfession($costumer["meslek"]);
        $userModel->setGenderId($costumer["cinsiyet_id"]);
        $userModel->setPhoneNumber($costumer["telefon"]);
        $userModel->setMailAddress($costumer["mail_adres"]);
        $userModel->setFirstLogin($costumer["ilk_giris"]);
        $userModel->setAuthorityId($costumer["yetki_id"]);

        return $userModel->toString();
    }

    public function __destruct(){
        parent::__destruct();
    }
}


?>