<?php

require_once(__DIR__ . '/WorkingService.php');
require_once(__DIR__ . '/../../Veritabani.php');
require_once(__DIR__ . '/../UserModel.php');

class WorkingServiceImp extends Veritabani implements WorkingService{

    public function __construct(){
        parent::__construct();
    }

    public function fetchAllEmployees(){
        $response = array();

        $queryAllEmployeesFetch = $this->baglanti->prepare("SELECT * FROM kullanicilar WHERE yetki_id = :yetki_id");
        $queryAllEmployeesFetch->bindValue(":yetki_id", parent::EMPLOYEE_AUTHORITY, PDO::PARAM_INT);
        $queryAllEmployeesFetch->execute();
        $employeesResponse = $queryAllEmployeesFetch->fetchAll(PDO::FETCH_ASSOC);

        if($employeesResponse){
            $response["users"] = array();

            foreach($employeesResponse as $employee){
                $employeeModel = $this->addWorkingModel($employee);
                array_push($response["users"],$employeeModel);
            }

            $response["success"] = parent::BASARILI;
            $response["message"]  = "Calisanlar başarıyla alındı";
        }else{
            $response["success"] = parent::BOS;
            $response["message"]  = "Çalışanlara ait bilgi bulunamadı";
        }

        return $response;
    }

    public function webAdminLogin($username, $password){
        $response = array();

        $managerAccessControl = $this->baglanti->prepare("SELECT * FROM kullanicilar WHERE kullanici_adi = :kullanici_adi 
                                                                                      AND kullanici_sifre = :kullanici_sifre AND yetki_id != :yetki_id");
        $managerAccessControl->bindValue(":kullanici_adi"  , $username    , PDO::PARAM_STR);
        $managerAccessControl->bindValue(":kullanici_sifre", $password, PDO::PARAM_STR);
        $managerAccessControl->bindValue(":yetki_id"       ,parent::COSTUMER_AUTHORITY);
        $managerAccessControl->execute();
        $managerResponse = $managerAccessControl->fetch(PDO::FETCH_ASSOC);

        if($managerResponse){
            session_start();

            $response["manager"]  = $this->addWorkingModel($managerResponse);
            $response["success"]  = parent::BASARILI;
            $response["message"]  = "Başarıyla giriş yapıldı";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Giriş bilgileri hatalı";
        }

        return $response;
    }

    
    public function updateEmployeeAuthorization($user_id){
        $response = array();

        $queryEmployeeAuthorization = $this->baglanti->prepare("UPDATE kullanicilar SET yetki_id = :yetki_id
                                                                WHERE musteri_id = :kullanici_id");
        $queryEmployeeAuthorization->bindValue(":yetki_id"    , parent::EMPLOYEE_AUTHORITY, PDO::PARAM_INT);
        $queryEmployeeAuthorization->bindValue(":kullanici_id", $user_id                  , PDO::PARAM_INT);
        $queryEmployeeAuthorization->execute();

        if($queryEmployeeAuthorization->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Çalışan başarıyla eklendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Çalışan eklenirken bir hata ile karşılaşıldı";
        }
        
        return $response;
    }

    public function updateEmployeeInformation($userModel){
        $response = array();

        $userId      = $userModel->getUserId();
        $name        = $userModel->getName();
        $surname     = $userModel->getSurname();
        $birthday    = $userModel->getBirthday();
        $profession  = $userModel->getProfession();

        $queryCostumerInformationUpdate = $this->baglanti->prepare("UPDATE kullanicilar SET
                                                            ad          = :ad,
                                                            soyad       = :soyad,
                                                            dogum_tarih = :dogum_tarih,
                                                            meslek      = :meslek
                                                            WHERE musteri_id    = :musteri_id");
        $queryCostumerInformationUpdate->bindValue(":ad"         , $name                  , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":soyad"      , $surname               , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":dogum_tarih", $birthday              , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":meslek"     , $profession            , PDO::PARAM_STR);
        $queryCostumerInformationUpdate->bindValue(":musteri_id" , $userId                , PDO::PARAM_INT);
        $queryCostumerInformationUpdate->execute();

        if($queryCostumerInformationUpdate->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Çalışan bilgileri başarıyla güncellendi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Çalışan bilgileri güncellenemedi";
        }

        return $response;
    }

    public function deleteEmployee($user_id){
        $response = array();

        $queryEmployeeAuthorization = $this->baglanti->prepare("UPDATE kullanicilar SET yetki_id = :yetki_id
                                                                WHERE musteri_id = :kullanici_id");
        $queryEmployeeAuthorization->bindValue(":yetki_id"    , parent::COSTUMER_AUTHORITY, PDO::PARAM_INT);
        $queryEmployeeAuthorization->bindValue(":kullanici_id", $user_id                  , PDO::PARAM_INT);
        $queryEmployeeAuthorization->execute();

        if($queryEmployeeAuthorization->rowCount() > 0){
            $response["success"] = parent::BASARILI;
            $response["message"] = "Çalışan başarıyla silindi";
        }else{
            $response["success"] = parent::BASARISIZ;
            $response["message"] = "Çalışan silinirken bir hata ile karşılaşıldı";
        }

        return $response;
    }

    public function addWorkingModel($employee){
        $userModel = new UserModel();

        $userModel->setUserId($employee["musteri_id"]);
        $userModel->setUserTc($employee["kullanici_tc"]);
        $userModel->setUserName($employee["kullanici_adi"]);
        $userModel->setProfilePhoto($employee["profil_fotograf"]);
        $userModel->setName($employee["ad"]);
        $userModel->setSurname($employee["soyad"]);
        $userModel->setBirthday($employee["dogum_tarih"]);
        $userModel->setAddress($employee["adres"]);
        $userModel->setProfession($employee["meslek"]);
        $userModel->setGenderId($employee["cinsiyet_id"]);
        $userModel->setPhoneNumber($employee["telefon"]);
        $userModel->setMailAddress($employee["mail_adres"]);
        $userModel->setFirstLogin($employee["ilk_giris"]);
        $userModel->setAuthorityId($employee["yetki_id"]);

        return $userModel->toString();
    }

    public function __destruct(){
        parent::__destruct();
    }

}

?>